# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: attestation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ttestation.proto\x12\x0b\x61ttestation\"\xf5\x01\n\x08\x46\x61tquote\x12)\n\x04\x65pid\x18\x01 \x01(\x0b\x32\x19.attestation.FatquoteEpidH\x00\x12)\n\x04\x64\x63\x61p\x18\x02 \x01(\x0b\x32\x19.attestation.FatquoteDcapH\x00\x12+\n\x05nitro\x18\x03 \x01(\x0b\x32\x1a.attestation.FatquoteNitroH\x00\x12\'\n\x03snp\x18\x04 \x01(\x0b\x32\x18.attestation.FatquoteSnpH\x00\x12\x31\n\x0c\x64\x63\x61pMrsigner\x18\x05 \x01(\x0b\x32\x19.attestation.FatquoteDcapH\x00\x42\n\n\x08\x66\x61tquote\"k\n\x0c\x46\x61tquoteEpid\x12\x17\n\x0fiasResponseBody\x18\x01 \x01(\x0c\x12\x16\n\x0eiasCertificate\x18\x02 \x01(\x0c\x12\x14\n\x0ciasSignature\x18\x03 \x01(\x0c\x12\x14\n\x0ciasRootCaDer\x18\x04 \x01(\x0c\"\x86\x01\n\x0c\x46\x61tquoteDcap\x12\x11\n\tdcapQuote\x18\x01 \x01(\x0c\x12\x0f\n\x07tcbInfo\x18\x02 \x01(\x0c\x12\x12\n\nqeIdentity\x18\x03 \x01(\x0c\x12\x13\n\x0btcbSignCert\x18\x04 \x01(\x0c\x12\x12\n\nqeSignCert\x18\x05 \x01(\x0c\x12\x15\n\rdcapRootCaDer\x18\x06 \x01(\x0c\"5\n\rFatquoteNitro\x12\x0c\n\x04\x63ose\x18\x01 \x01(\x0c\x12\x16\n\x0enitroRootCaDer\x18\x02 \x01(\x0c\"\xdf\x01\n\x0b\x46\x61tquoteSnp\x12\x11\n\treportBin\x18\x01 \x01(\x0c\x12\x11\n\tamdArkDer\x18\x02 \x01(\x0c\x12\x11\n\tamdSevDer\x18\x03 \x01(\x0c\x12\x12\n\nvcekCrtDer\x18\x04 \x01(\x0c\x12\x12\n\nreportData\x18\x05 \x01(\x0c\x12\x17\n\x0froughtimePubKey\x18\x06 \x01(\x0c\x12\x16\n\x0eroughtimeNonce\x18\x07 \x01(\x0c\x12\x17\n\x0fsignedTimestamp\x18\x08 \x01(\x0c\x12\x14\n\x0c\x64\x65\x63\x65ntriqDer\x18\t \x01(\x0c\x12\x0f\n\x07\x63hipDer\x18\n \x01(\x0c\"\x98\x03\n\x18\x41ttestationSpecification\x12\x43\n\tintelEpid\x18\x01 \x01(\x0b\x32..attestation.AttestationSpecificationIntelEpidH\x00\x12\x43\n\tintelDcap\x18\x02 \x01(\x0b\x32..attestation.AttestationSpecificationIntelDcapH\x00\x12\x41\n\x08\x61wsNitro\x18\x03 \x01(\x0b\x32-.attestation.AttestationSpecificationAwsNitroH\x00\x12=\n\x06\x61mdSnp\x18\x04 \x01(\x0b\x32+.attestation.AttestationSpecificationAmdSnpH\x00\x12S\n\x11intelDcapMrsigner\x18\x05 \x01(\x0b\x32\x36.attestation.AttestationSpecificationIntelDcapMrsignerH\x00\x42\x1b\n\x19\x61ttestation_specification\"\xa9\x01\n!AttestationSpecificationIntelEpid\x12\x11\n\tmrenclave\x18\x01 \x01(\x0c\x12\x14\n\x0ciasRootCaDer\x18\x02 \x01(\x0c\x12\x14\n\x0c\x61\x63\x63\x65pt_debug\x18\x03 \x01(\x08\x12 \n\x18\x61\x63\x63\x65pt_group_out_of_date\x18\x04 \x01(\x08\x12#\n\x1b\x61\x63\x63\x65pt_configuration_needed\x18\x05 \x01(\x08\"\xbc\x01\n!AttestationSpecificationIntelDcap\x12\x11\n\tmrenclave\x18\x01 \x01(\x0c\x12\x15\n\rdcapRootCaDer\x18\x02 \x01(\x0c\x12\x14\n\x0c\x61\x63\x63\x65pt_debug\x18\x03 \x01(\x08\x12\x1a\n\x12\x61\x63\x63\x65pt_out_of_date\x18\x04 \x01(\x08\x12#\n\x1b\x61\x63\x63\x65pt_configuration_needed\x18\x05 \x01(\x08\x12\x16\n\x0e\x61\x63\x63\x65pt_revoked\x18\x06 \x01(\x08\"r\n AttestationSpecificationAwsNitro\x12\x16\n\x0enitroRootCaDer\x18\x01 \x01(\x0c\x12\x0c\n\x04pcr0\x18\x02 \x01(\x0c\x12\x0c\n\x04pcr1\x18\x03 \x01(\x0c\x12\x0c\n\x04pcr2\x18\x04 \x01(\x0c\x12\x0c\n\x04pcr8\x18\x05 \x01(\x0c\"\x92\x01\n\x1e\x41ttestationSpecificationAmdSnp\x12\x11\n\tamdArkDer\x18\x01 \x01(\x0c\x12\x13\n\x0bmeasurement\x18\x02 \x01(\x0c\x12\x17\n\x0froughtimePubKey\x18\x03 \x01(\x0c\x12\x19\n\x11\x61uthorizedChipIds\x18\x04 \x03(\x0c\x12\x14\n\x0c\x64\x65\x63\x65ntriqDer\x18\x05 \x01(\x0c\"\xd6\x01\n)AttestationSpecificationIntelDcapMrsigner\x12\x10\n\x08mrsigner\x18\x01 \x01(\x0c\x12\x11\n\tisvprodid\x18\x07 \x01(\r\x12\x15\n\rdcapRootCaDer\x18\x02 \x01(\x0c\x12\x14\n\x0c\x61\x63\x63\x65pt_debug\x18\x03 \x01(\x08\x12\x1a\n\x12\x61\x63\x63\x65pt_out_of_date\x18\x04 \x01(\x08\x12#\n\x1b\x61\x63\x63\x65pt_configuration_needed\x18\x05 \x01(\x08\x12\x16\n\x0e\x61\x63\x63\x65pt_revoked\x18\x06 \x01(\x08\x62\x06proto3')



_FATQUOTE = DESCRIPTOR.message_types_by_name['Fatquote']
_FATQUOTEEPID = DESCRIPTOR.message_types_by_name['FatquoteEpid']
_FATQUOTEDCAP = DESCRIPTOR.message_types_by_name['FatquoteDcap']
_FATQUOTENITRO = DESCRIPTOR.message_types_by_name['FatquoteNitro']
_FATQUOTESNP = DESCRIPTOR.message_types_by_name['FatquoteSnp']
_ATTESTATIONSPECIFICATION = DESCRIPTOR.message_types_by_name['AttestationSpecification']
_ATTESTATIONSPECIFICATIONINTELEPID = DESCRIPTOR.message_types_by_name['AttestationSpecificationIntelEpid']
_ATTESTATIONSPECIFICATIONINTELDCAP = DESCRIPTOR.message_types_by_name['AttestationSpecificationIntelDcap']
_ATTESTATIONSPECIFICATIONAWSNITRO = DESCRIPTOR.message_types_by_name['AttestationSpecificationAwsNitro']
_ATTESTATIONSPECIFICATIONAMDSNP = DESCRIPTOR.message_types_by_name['AttestationSpecificationAmdSnp']
_ATTESTATIONSPECIFICATIONINTELDCAPMRSIGNER = DESCRIPTOR.message_types_by_name['AttestationSpecificationIntelDcapMrsigner']
Fatquote = _reflection.GeneratedProtocolMessageType('Fatquote', (_message.Message,), {
  'DESCRIPTOR' : _FATQUOTE,
  '__module__' : 'attestation_pb2'
  # @@protoc_insertion_point(class_scope:attestation.Fatquote)
  })
_sym_db.RegisterMessage(Fatquote)

FatquoteEpid = _reflection.GeneratedProtocolMessageType('FatquoteEpid', (_message.Message,), {
  'DESCRIPTOR' : _FATQUOTEEPID,
  '__module__' : 'attestation_pb2'
  # @@protoc_insertion_point(class_scope:attestation.FatquoteEpid)
  })
_sym_db.RegisterMessage(FatquoteEpid)

FatquoteDcap = _reflection.GeneratedProtocolMessageType('FatquoteDcap', (_message.Message,), {
  'DESCRIPTOR' : _FATQUOTEDCAP,
  '__module__' : 'attestation_pb2'
  # @@protoc_insertion_point(class_scope:attestation.FatquoteDcap)
  })
_sym_db.RegisterMessage(FatquoteDcap)

FatquoteNitro = _reflection.GeneratedProtocolMessageType('FatquoteNitro', (_message.Message,), {
  'DESCRIPTOR' : _FATQUOTENITRO,
  '__module__' : 'attestation_pb2'
  # @@protoc_insertion_point(class_scope:attestation.FatquoteNitro)
  })
_sym_db.RegisterMessage(FatquoteNitro)

FatquoteSnp = _reflection.GeneratedProtocolMessageType('FatquoteSnp', (_message.Message,), {
  'DESCRIPTOR' : _FATQUOTESNP,
  '__module__' : 'attestation_pb2'
  # @@protoc_insertion_point(class_scope:attestation.FatquoteSnp)
  })
_sym_db.RegisterMessage(FatquoteSnp)

AttestationSpecification = _reflection.GeneratedProtocolMessageType('AttestationSpecification', (_message.Message,), {
  'DESCRIPTOR' : _ATTESTATIONSPECIFICATION,
  '__module__' : 'attestation_pb2'
  # @@protoc_insertion_point(class_scope:attestation.AttestationSpecification)
  })
_sym_db.RegisterMessage(AttestationSpecification)

AttestationSpecificationIntelEpid = _reflection.GeneratedProtocolMessageType('AttestationSpecificationIntelEpid', (_message.Message,), {
  'DESCRIPTOR' : _ATTESTATIONSPECIFICATIONINTELEPID,
  '__module__' : 'attestation_pb2'
  # @@protoc_insertion_point(class_scope:attestation.AttestationSpecificationIntelEpid)
  })
_sym_db.RegisterMessage(AttestationSpecificationIntelEpid)

AttestationSpecificationIntelDcap = _reflection.GeneratedProtocolMessageType('AttestationSpecificationIntelDcap', (_message.Message,), {
  'DESCRIPTOR' : _ATTESTATIONSPECIFICATIONINTELDCAP,
  '__module__' : 'attestation_pb2'
  # @@protoc_insertion_point(class_scope:attestation.AttestationSpecificationIntelDcap)
  })
_sym_db.RegisterMessage(AttestationSpecificationIntelDcap)

AttestationSpecificationAwsNitro = _reflection.GeneratedProtocolMessageType('AttestationSpecificationAwsNitro', (_message.Message,), {
  'DESCRIPTOR' : _ATTESTATIONSPECIFICATIONAWSNITRO,
  '__module__' : 'attestation_pb2'
  # @@protoc_insertion_point(class_scope:attestation.AttestationSpecificationAwsNitro)
  })
_sym_db.RegisterMessage(AttestationSpecificationAwsNitro)

AttestationSpecificationAmdSnp = _reflection.GeneratedProtocolMessageType('AttestationSpecificationAmdSnp', (_message.Message,), {
  'DESCRIPTOR' : _ATTESTATIONSPECIFICATIONAMDSNP,
  '__module__' : 'attestation_pb2'
  # @@protoc_insertion_point(class_scope:attestation.AttestationSpecificationAmdSnp)
  })
_sym_db.RegisterMessage(AttestationSpecificationAmdSnp)

AttestationSpecificationIntelDcapMrsigner = _reflection.GeneratedProtocolMessageType('AttestationSpecificationIntelDcapMrsigner', (_message.Message,), {
  'DESCRIPTOR' : _ATTESTATIONSPECIFICATIONINTELDCAPMRSIGNER,
  '__module__' : 'attestation_pb2'
  # @@protoc_insertion_point(class_scope:attestation.AttestationSpecificationIntelDcapMrsigner)
  })
_sym_db.RegisterMessage(AttestationSpecificationIntelDcapMrsigner)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FATQUOTE._serialized_start=35
  _FATQUOTE._serialized_end=280
  _FATQUOTEEPID._serialized_start=282
  _FATQUOTEEPID._serialized_end=389
  _FATQUOTEDCAP._serialized_start=392
  _FATQUOTEDCAP._serialized_end=526
  _FATQUOTENITRO._serialized_start=528
  _FATQUOTENITRO._serialized_end=581
  _FATQUOTESNP._serialized_start=584
  _FATQUOTESNP._serialized_end=807
  _ATTESTATIONSPECIFICATION._serialized_start=810
  _ATTESTATIONSPECIFICATION._serialized_end=1218
  _ATTESTATIONSPECIFICATIONINTELEPID._serialized_start=1221
  _ATTESTATIONSPECIFICATIONINTELEPID._serialized_end=1390
  _ATTESTATIONSPECIFICATIONINTELDCAP._serialized_start=1393
  _ATTESTATIONSPECIFICATIONINTELDCAP._serialized_end=1581
  _ATTESTATIONSPECIFICATIONAWSNITRO._serialized_start=1583
  _ATTESTATIONSPECIFICATIONAWSNITRO._serialized_end=1697
  _ATTESTATIONSPECIFICATIONAMDSNP._serialized_start=1700
  _ATTESTATIONSPECIFICATIONAMDSNP._serialized_end=1846
  _ATTESTATIONSPECIFICATIONINTELDCAPMRSIGNER._serialized_start=1849
  _ATTESTATIONSPECIFICATIONINTELDCAPMRSIGNER._serialized_end=2063
# @@protoc_insertion_point(module_scope)



from typing import List, Any, Optional
import uuid


__all__ = ["Node"]


class Node:
    name: str
    """The name of the node."""

    config: bytes
    """Serialized configuration to use in the compute node definition."""

    enclave_type: str
    """What type of enclave this node uses."""

    dependencies: List[str]
    """A list of names of nodes on which this node directly depends."""

    output_format: Any
    """The `proto.ComputeNodeFormat` of the output from this node."""

    def __init__(
        self,
        name: str,
        config: bytes,
        enclave_type: str,
        dependencies: List[str],
        output_format: Any,
    ):
        self.name = name
        self.config = config
        self.enclave_type = enclave_type
        self.dependencies = dependencies
        self.output_format = output_format



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import attestation_pb2
import builtins
import collections.abc
import data_room_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _CreateDcrPurpose:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CreateDcrPurposeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CreateDcrPurpose.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    STANDARD: _CreateDcrPurpose.ValueType  # 0
    VALIDATION: _CreateDcrPurpose.ValueType  # 1
    DATA_IMPORT: _CreateDcrPurpose.ValueType  # 2
    DATA_EXPORT: _CreateDcrPurpose.ValueType  # 3
    DATA_LAB: _CreateDcrPurpose.ValueType  # 4

class CreateDcrPurpose(_CreateDcrPurpose, metaclass=_CreateDcrPurposeEnumTypeWrapper): ...

STANDARD: CreateDcrPurpose.ValueType  # 0
VALIDATION: CreateDcrPurpose.ValueType  # 1
DATA_IMPORT: CreateDcrPurpose.ValueType  # 2
DATA_EXPORT: CreateDcrPurpose.ValueType  # 3
DATA_LAB: CreateDcrPurpose.ValueType  # 4
global___CreateDcrPurpose = CreateDcrPurpose

class _CreateDcrKind:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CreateDcrKindEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CreateDcrKind.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    EXPERT: _CreateDcrKind.ValueType  # 0
    DATASCIENCE: _CreateDcrKind.ValueType  # 1
    MEDIA: _CreateDcrKind.ValueType  # 2
    LOOKALIKE_MEDIA: _CreateDcrKind.ValueType  # 3

class CreateDcrKind(_CreateDcrKind, metaclass=_CreateDcrKindEnumTypeWrapper): ...

EXPERT: CreateDcrKind.ValueType  # 0
DATASCIENCE: CreateDcrKind.ValueType  # 1
MEDIA: CreateDcrKind.ValueType  # 2
LOOKALIKE_MEDIA: CreateDcrKind.ValueType  # 3
global___CreateDcrKind = CreateDcrKind

@typing_extensions.final
class EnclaveInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ATTESTATIONSPECHASHHEX_FIELD_NUMBER: builtins.int
    TASKQUEUENAME_FIELD_NUMBER: builtins.int
    attestationSpecHashHex: builtins.str
    taskQueueName: builtins.str
    def __init__(
        self,
        *,
        attestationSpecHashHex: builtins.str = ...,
        taskQueueName: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_taskQueueName", b"_taskQueueName", "taskQueueName", b"taskQueueName"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_taskQueueName", b"_taskQueueName", "attestationSpecHashHex", b"attestationSpecHashHex", "taskQueueName", b"taskQueueName"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_taskQueueName", b"_taskQueueName"]) -> typing_extensions.Literal["taskQueueName"] | None: ...

global___EnclaveInfo = EnclaveInfo

@typing_extensions.final
class MeteringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATEDCR_FIELD_NUMBER: builtins.int
    CREATEDCRCOMMIT_FIELD_NUMBER: builtins.int
    STOPDCR_FIELD_NUMBER: builtins.int
    PUBLISHDATASET_FIELD_NUMBER: builtins.int
    UNPUBLISHDATASET_FIELD_NUMBER: builtins.int
    WORKERMETADATA_FIELD_NUMBER: builtins.int
    SUBMITWORKEREXECUTIONTIME_FIELD_NUMBER: builtins.int
    DCRINTERACTION_FIELD_NUMBER: builtins.int
    CREATEDATASET_FIELD_NUMBER: builtins.int
    GETORCREATEDATASETSCOPE_FIELD_NUMBER: builtins.int
    MERGEDCRCOMMIT_FIELD_NUMBER: builtins.int
    @property
    def createDcr(self) -> global___CreateDcrRequest: ...
    @property
    def createDcrCommit(self) -> global___CreateDcrCommitRequest: ...
    @property
    def stopDcr(self) -> global___StopDcrRequest: ...
    @property
    def publishDataset(self) -> global___PublishDatasetRequest: ...
    @property
    def unpublishDataset(self) -> global___UnpublishDatasetRequest: ...
    @property
    def workerMetadata(self) -> global___WorkerMetadataRequest: ...
    @property
    def submitWorkerExecutionTime(self) -> global___SubmitWorkerExecutionTimeRequest: ...
    @property
    def dcrInteraction(self) -> global___DcrInteractionRequest: ...
    @property
    def createDataset(self) -> global___CreateDatasetRequest: ...
    @property
    def getOrCreateDatasetScope(self) -> global___GetOrCreateDatasetScopeRequest: ...
    @property
    def mergeDcrCommit(self) -> global___MergeDcrCommitRequest: ...
    def __init__(
        self,
        *,
        createDcr: global___CreateDcrRequest | None = ...,
        createDcrCommit: global___CreateDcrCommitRequest | None = ...,
        stopDcr: global___StopDcrRequest | None = ...,
        publishDataset: global___PublishDatasetRequest | None = ...,
        unpublishDataset: global___UnpublishDatasetRequest | None = ...,
        workerMetadata: global___WorkerMetadataRequest | None = ...,
        submitWorkerExecutionTime: global___SubmitWorkerExecutionTimeRequest | None = ...,
        dcrInteraction: global___DcrInteractionRequest | None = ...,
        createDataset: global___CreateDatasetRequest | None = ...,
        getOrCreateDatasetScope: global___GetOrCreateDatasetScopeRequest | None = ...,
        mergeDcrCommit: global___MergeDcrCommitRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["createDataset", b"createDataset", "createDcr", b"createDcr", "createDcrCommit", b"createDcrCommit", "dcrInteraction", b"dcrInteraction", "getOrCreateDatasetScope", b"getOrCreateDatasetScope", "mergeDcrCommit", b"mergeDcrCommit", "publishDataset", b"publishDataset", "request", b"request", "stopDcr", b"stopDcr", "submitWorkerExecutionTime", b"submitWorkerExecutionTime", "unpublishDataset", b"unpublishDataset", "workerMetadata", b"workerMetadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["createDataset", b"createDataset", "createDcr", b"createDcr", "createDcrCommit", b"createDcrCommit", "dcrInteraction", b"dcrInteraction", "getOrCreateDatasetScope", b"getOrCreateDatasetScope", "mergeDcrCommit", b"mergeDcrCommit", "publishDataset", b"publishDataset", "request", b"request", "stopDcr", b"stopDcr", "submitWorkerExecutionTime", b"submitWorkerExecutionTime", "unpublishDataset", b"unpublishDataset", "workerMetadata", b"workerMetadata"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["request", b"request"]) -> typing_extensions.Literal["createDcr", "createDcrCommit", "stopDcr", "publishDataset", "unpublishDataset", "workerMetadata", "submitWorkerExecutionTime", "dcrInteraction", "createDataset", "getOrCreateDatasetScope", "mergeDcrCommit"] | None: ...

global___MeteringRequest = MeteringRequest

@typing_extensions.final
class MeteringSuccessResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATEDCR_FIELD_NUMBER: builtins.int
    CREATEDCRCOMMIT_FIELD_NUMBER: builtins.int
    STOPDCR_FIELD_NUMBER: builtins.int
    PUBLISHDATASET_FIELD_NUMBER: builtins.int
    UNPUBLISHDATASET_FIELD_NUMBER: builtins.int
    WORKERMETADATA_FIELD_NUMBER: builtins.int
    SUBMITWORKEREXECUTIONTIME_FIELD_NUMBER: builtins.int
    DCRINTERACTION_FIELD_NUMBER: builtins.int
    CREATEDATASET_FIELD_NUMBER: builtins.int
    GETORCREATEDATASETSCOPE_FIELD_NUMBER: builtins.int
    MERGEDCRCOMMIT_FIELD_NUMBER: builtins.int
    @property
    def createDcr(self) -> global___CreateDcrResponse: ...
    @property
    def createDcrCommit(self) -> global___CreateDcrCommitResponse: ...
    @property
    def stopDcr(self) -> global___StopDcrResponse: ...
    @property
    def publishDataset(self) -> global___PublishDatasetResponse: ...
    @property
    def unpublishDataset(self) -> global___UnpublishDatasetResponse: ...
    @property
    def workerMetadata(self) -> global___WorkerMetadataResponse: ...
    @property
    def submitWorkerExecutionTime(self) -> global___SubmitWorkerExecutionTimeResponse: ...
    @property
    def dcrInteraction(self) -> global___DcrInteractionResponse: ...
    @property
    def createDataset(self) -> global___CreateDatasetResponse: ...
    @property
    def getOrCreateDatasetScope(self) -> global___GetOrCreateDatasetScopeResponse: ...
    @property
    def mergeDcrCommit(self) -> global___MergeDcrCommitResponse: ...
    def __init__(
        self,
        *,
        createDcr: global___CreateDcrResponse | None = ...,
        createDcrCommit: global___CreateDcrCommitResponse | None = ...,
        stopDcr: global___StopDcrResponse | None = ...,
        publishDataset: global___PublishDatasetResponse | None = ...,
        unpublishDataset: global___UnpublishDatasetResponse | None = ...,
        workerMetadata: global___WorkerMetadataResponse | None = ...,
        submitWorkerExecutionTime: global___SubmitWorkerExecutionTimeResponse | None = ...,
        dcrInteraction: global___DcrInteractionResponse | None = ...,
        createDataset: global___CreateDatasetResponse | None = ...,
        getOrCreateDatasetScope: global___GetOrCreateDatasetScopeResponse | None = ...,
        mergeDcrCommit: global___MergeDcrCommitResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["createDataset", b"createDataset", "createDcr", b"createDcr", "createDcrCommit", b"createDcrCommit", "dcrInteraction", b"dcrInteraction", "getOrCreateDatasetScope", b"getOrCreateDatasetScope", "mergeDcrCommit", b"mergeDcrCommit", "publishDataset", b"publishDataset", "response", b"response", "stopDcr", b"stopDcr", "submitWorkerExecutionTime", b"submitWorkerExecutionTime", "unpublishDataset", b"unpublishDataset", "workerMetadata", b"workerMetadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["createDataset", b"createDataset", "createDcr", b"createDcr", "createDcrCommit", b"createDcrCommit", "dcrInteraction", b"dcrInteraction", "getOrCreateDatasetScope", b"getOrCreateDatasetScope", "mergeDcrCommit", b"mergeDcrCommit", "publishDataset", b"publishDataset", "response", b"response", "stopDcr", b"stopDcr", "submitWorkerExecutionTime", b"submitWorkerExecutionTime", "unpublishDataset", b"unpublishDataset", "workerMetadata", b"workerMetadata"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["response", b"response"]) -> typing_extensions.Literal["createDcr", "createDcrCommit", "stopDcr", "publishDataset", "unpublishDataset", "workerMetadata", "submitWorkerExecutionTime", "dcrInteraction", "createDataset", "getOrCreateDatasetScope", "mergeDcrCommit"] | None: ...

global___MeteringSuccessResponse = MeteringSuccessResponse

@typing_extensions.final
class MeteringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    FAILURE_FIELD_NUMBER: builtins.int
    @property
    def success(self) -> global___MeteringSuccessResponse: ...
    failure: builtins.str
    def __init__(
        self,
        *,
        success: global___MeteringSuccessResponse | None = ...,
        failure: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["failure", b"failure", "response", b"response", "success", b"success"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["failure", b"failure", "response", b"response", "success", b"success"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["response", b"response"]) -> typing_extensions.Literal["success", "failure"] | None: ...

global___MeteringResponse = MeteringResponse

@typing_extensions.final
class DcrMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PURPOSE_FIELD_NUMBER: builtins.int
    SHOWORGANIZATIONLOGO_FIELD_NUMBER: builtins.int
    REQUIREPASSWORD_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    purpose: global___CreateDcrPurpose.ValueType
    """/ Why this data room is being created (allows for purpose-based filtering of data rooms)"""
    showOrganizationLogo: builtins.bool
    """/ Whether to show the organization logo"""
    requirePassword: builtins.bool
    """/ Whether the DCR requires a password"""
    kind: global___CreateDcrKind.ValueType
    """/ The dcr type"""
    def __init__(
        self,
        *,
        purpose: global___CreateDcrPurpose.ValueType = ...,
        showOrganizationLogo: builtins.bool = ...,
        requirePassword: builtins.bool = ...,
        kind: global___CreateDcrKind.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kind", b"kind", "purpose", b"purpose", "requirePassword", b"requirePassword", "showOrganizationLogo", b"showOrganizationLogo"]) -> None: ...

global___DcrMetadata = DcrMetadata

@typing_extensions.final
class CreateDcrRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDHEX_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DRIVERATTESTATIONHASH_FIELD_NUMBER: builtins.int
    PARTICIPANTEMAILS_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    ENCLAVEINFO_FIELD_NUMBER: builtins.int
    idHex: builtins.str
    """/ The DCR hash to be used for the published data room"""
    name: builtins.str
    driverAttestationHash: builtins.str
    """/ The driver attestation hash"""
    @property
    def participantEmails(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    metadata: builtins.bytes
    """/ Optional metadata that will be persisted to the database"""
    @property
    def enclaveInfo(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EnclaveInfo]:
        """/ Information about the enclaves used in this DCR"""
    def __init__(
        self,
        *,
        idHex: builtins.str = ...,
        name: builtins.str = ...,
        driverAttestationHash: builtins.str = ...,
        participantEmails: collections.abc.Iterable[builtins.str] | None = ...,
        metadata: builtins.bytes | None = ...,
        enclaveInfo: collections.abc.Iterable[global___EnclaveInfo] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_metadata", b"_metadata", "metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_metadata", b"_metadata", "driverAttestationHash", b"driverAttestationHash", "enclaveInfo", b"enclaveInfo", "idHex", b"idHex", "metadata", b"metadata", "name", b"name", "participantEmails", b"participantEmails"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_metadata", b"_metadata"]) -> typing_extensions.Literal["metadata"] | None: ...

global___CreateDcrRequest = CreateDcrRequest

@typing_extensions.final
class ExecuteComputationNodeInteraction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODEID_FIELD_NUMBER: builtins.int
    RATELIMITING_FIELD_NUMBER: builtins.int
    nodeId: builtins.str
    @property
    def rateLimiting(self) -> data_room_pb2.RateLimitingConfig:
        """The rate limiting config that was defined within the DCR for this node (if any)"""
    def __init__(
        self,
        *,
        nodeId: builtins.str = ...,
        rateLimiting: data_room_pb2.RateLimitingConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_rateLimiting", b"_rateLimiting", "rateLimiting", b"rateLimiting"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_rateLimiting", b"_rateLimiting", "nodeId", b"nodeId", "rateLimiting", b"rateLimiting"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_rateLimiting", b"_rateLimiting"]) -> typing_extensions.Literal["rateLimiting"] | None: ...

global___ExecuteComputationNodeInteraction = ExecuteComputationNodeInteraction

@typing_extensions.final
class ExecuteComputationInteraction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODES_FIELD_NUMBER: builtins.int
    @property
    def nodes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ExecuteComputationNodeInteraction]: ...
    def __init__(
        self,
        *,
        nodes: collections.abc.Iterable[global___ExecuteComputationNodeInteraction] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nodes", b"nodes"]) -> None: ...

global___ExecuteComputationInteraction = ExecuteComputationInteraction

@typing_extensions.final
class PublishDatasetInteraction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODEID_FIELD_NUMBER: builtins.int
    RATELIMITING_FIELD_NUMBER: builtins.int
    nodeId: builtins.str
    @property
    def rateLimiting(self) -> data_room_pb2.RateLimitingConfig:
        """The rate limiting config that was defined within the DCR for this node (if any)"""
    def __init__(
        self,
        *,
        nodeId: builtins.str = ...,
        rateLimiting: data_room_pb2.RateLimitingConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_rateLimiting", b"_rateLimiting", "rateLimiting", b"rateLimiting"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_rateLimiting", b"_rateLimiting", "nodeId", b"nodeId", "rateLimiting", b"rateLimiting"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_rateLimiting", b"_rateLimiting"]) -> typing_extensions.Literal["rateLimiting"] | None: ...

global___PublishDatasetInteraction = PublishDatasetInteraction

@typing_extensions.final
class DcrInteractionKind(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTECOMPUTATION_FIELD_NUMBER: builtins.int
    PUBLISHDATASET_FIELD_NUMBER: builtins.int
    @property
    def executeComputation(self) -> global___ExecuteComputationInteraction: ...
    @property
    def publishDataset(self) -> global___PublishDatasetInteraction: ...
    def __init__(
        self,
        *,
        executeComputation: global___ExecuteComputationInteraction | None = ...,
        publishDataset: global___PublishDatasetInteraction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["executeComputation", b"executeComputation", "kind", b"kind", "publishDataset", b"publishDataset"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["executeComputation", b"executeComputation", "kind", b"kind", "publishDataset", b"publishDataset"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["kind", b"kind"]) -> typing_extensions.Literal["executeComputation", "publishDataset"] | None: ...

global___DcrInteractionKind = DcrInteractionKind

@typing_extensions.final
class DcrInteractionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATAROOMHASH_FIELD_NUMBER: builtins.int
    DRIVERATTESTATIONHASH_FIELD_NUMBER: builtins.int
    SCOPEID_FIELD_NUMBER: builtins.int
    INTERACTION_FIELD_NUMBER: builtins.int
    dataRoomHash: builtins.str
    """/ The hex-encoded hash of the data room"""
    driverAttestationHash: builtins.str
    """/ The driver attestation hash"""
    scopeId: builtins.str
    """Id of the scope to check"""
    @property
    def interaction(self) -> global___DcrInteractionKind:
        """The type of interactions the user wants to perform"""
    def __init__(
        self,
        *,
        dataRoomHash: builtins.str = ...,
        driverAttestationHash: builtins.str = ...,
        scopeId: builtins.str = ...,
        interaction: global___DcrInteractionKind | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["interaction", b"interaction"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dataRoomHash", b"dataRoomHash", "driverAttestationHash", b"driverAttestationHash", "interaction", b"interaction", "scopeId", b"scopeId"]) -> None: ...

global___DcrInteractionRequest = DcrInteractionRequest

@typing_extensions.final
class PublishDatasetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPUTENODEID_FIELD_NUMBER: builtins.int
    MANIFESTHASH_FIELD_NUMBER: builtins.int
    DATAROOMHASH_FIELD_NUMBER: builtins.int
    DRIVERATTESTATIONHASH_FIELD_NUMBER: builtins.int
    computeNodeId: builtins.str
    """/ The UUID of the compute node to which this dataset is being published"""
    manifestHash: builtins.str
    """/ The hex-encoded manifest hash of the dataset"""
    dataRoomHash: builtins.str
    """/ The hex-encoded hash of the data room"""
    driverAttestationHash: builtins.str
    """/ The driver attestation hash"""
    def __init__(
        self,
        *,
        computeNodeId: builtins.str = ...,
        manifestHash: builtins.str = ...,
        dataRoomHash: builtins.str = ...,
        driverAttestationHash: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["computeNodeId", b"computeNodeId", "dataRoomHash", b"dataRoomHash", "driverAttestationHash", b"driverAttestationHash", "manifestHash", b"manifestHash"]) -> None: ...

global___PublishDatasetRequest = PublishDatasetRequest

@typing_extensions.final
class CreateDatasetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MANIFESTHASH_FIELD_NUMBER: builtins.int
    MANIFEST_FIELD_NUMBER: builtins.int
    SCOPEID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SIZEBYTES_FIELD_NUMBER: builtins.int
    STATISTICS_FIELD_NUMBER: builtins.int
    DATASETIMPORTID_FIELD_NUMBER: builtins.int
    manifestHash: builtins.str
    """/ The hex-encoded manifest hash of the dataset"""
    manifest: builtins.str
    """/ The hex-encoded manifest of the dataset"""
    scopeId: builtins.str
    """/ The id scope of the scope to which this dataset should be linked"""
    name: builtins.str
    """/ A human-readable name of the dataset that helps to identify it"""
    description: builtins.str
    """/ A human-readable description of the dataset that helps to identify it"""
    sizeBytes: builtins.int
    """/ The size of this dataset in bytes"""
    statistics: builtins.str
    """/ Statistics associated with this dataset as a serialized JSON object"""
    datasetImportId: builtins.str
    """/ An id identifying the dataset import as part of which this dataset was created"""
    def __init__(
        self,
        *,
        manifestHash: builtins.str = ...,
        manifest: builtins.str | None = ...,
        scopeId: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str | None = ...,
        sizeBytes: builtins.int | None = ...,
        statistics: builtins.str | None = ...,
        datasetImportId: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_datasetImportId", b"_datasetImportId", "_description", b"_description", "_manifest", b"_manifest", "_sizeBytes", b"_sizeBytes", "_statistics", b"_statistics", "datasetImportId", b"datasetImportId", "description", b"description", "manifest", b"manifest", "sizeBytes", b"sizeBytes", "statistics", b"statistics"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_datasetImportId", b"_datasetImportId", "_description", b"_description", "_manifest", b"_manifest", "_sizeBytes", b"_sizeBytes", "_statistics", b"_statistics", "datasetImportId", b"datasetImportId", "description", b"description", "manifest", b"manifest", "manifestHash", b"manifestHash", "name", b"name", "scopeId", b"scopeId", "sizeBytes", b"sizeBytes", "statistics", b"statistics"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_datasetImportId", b"_datasetImportId"]) -> typing_extensions.Literal["datasetImportId"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_description", b"_description"]) -> typing_extensions.Literal["description"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_manifest", b"_manifest"]) -> typing_extensions.Literal["manifest"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_sizeBytes", b"_sizeBytes"]) -> typing_extensions.Literal["sizeBytes"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_statistics", b"_statistics"]) -> typing_extensions.Literal["statistics"] | None: ...

global___CreateDatasetRequest = CreateDatasetRequest

@typing_extensions.final
class GetOrCreateDatasetScopeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MANIFESTHASH_FIELD_NUMBER: builtins.int
    manifestHash: builtins.str
    def __init__(
        self,
        *,
        manifestHash: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_manifestHash", b"_manifestHash", "manifestHash", b"manifestHash"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_manifestHash", b"_manifestHash", "manifestHash", b"manifestHash"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_manifestHash", b"_manifestHash"]) -> typing_extensions.Literal["manifestHash"] | None: ...

global___GetOrCreateDatasetScopeRequest = GetOrCreateDatasetScopeRequest

@typing_extensions.final
class UnpublishDatasetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPUTENODEID_FIELD_NUMBER: builtins.int
    DATAROOMHASH_FIELD_NUMBER: builtins.int
    DRIVERATTESTATIONHASH_FIELD_NUMBER: builtins.int
    computeNodeId: builtins.str
    """/ The UUID of the compute node to which this dataset is being published"""
    dataRoomHash: builtins.str
    """/ The hex-encoded hash of the data room"""
    driverAttestationHash: builtins.str
    """/ The driver attestation hash"""
    def __init__(
        self,
        *,
        computeNodeId: builtins.str = ...,
        dataRoomHash: builtins.str = ...,
        driverAttestationHash: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["computeNodeId", b"computeNodeId", "dataRoomHash", b"dataRoomHash", "driverAttestationHash", b"driverAttestationHash"]) -> None: ...

global___UnpublishDatasetRequest = UnpublishDatasetRequest

@typing_extensions.final
class StopDcrRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATAROOMHASH_FIELD_NUMBER: builtins.int
    DRIVERATTESTATIONHASH_FIELD_NUMBER: builtins.int
    dataRoomHash: builtins.str
    """/ The hex-encoded data room hash"""
    driverAttestationHash: builtins.str
    """/ The driver attestation hash"""
    def __init__(
        self,
        *,
        dataRoomHash: builtins.str = ...,
        driverAttestationHash: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dataRoomHash", b"dataRoomHash", "driverAttestationHash", b"driverAttestationHash"]) -> None: ...

global___StopDcrRequest = StopDcrRequest

@typing_extensions.final
class CreateDcrCommitRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    DCRIDHEX_FIELD_NUMBER: builtins.int
    DRIVERATTESTATIONHASH_FIELD_NUMBER: builtins.int
    ENCLAVEINFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    """/ The commit id"""
    dcrIdHex: builtins.str
    """/ The DCR hash the commit refers to"""
    driverAttestationHash: builtins.str
    """/ The driver attestation hash"""
    @property
    def enclaveInfo(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EnclaveInfo]:
        """/ Information about the enclaves used in this commit"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        dcrIdHex: builtins.str = ...,
        driverAttestationHash: builtins.str = ...,
        enclaveInfo: collections.abc.Iterable[global___EnclaveInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dcrIdHex", b"dcrIdHex", "driverAttestationHash", b"driverAttestationHash", "enclaveInfo", b"enclaveInfo", "id", b"id"]) -> None: ...

global___CreateDcrCommitRequest = CreateDcrCommitRequest

@typing_extensions.final
class MergeDcrCommitRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    DCRIDHEX_FIELD_NUMBER: builtins.int
    DRIVERATTESTATIONHASH_FIELD_NUMBER: builtins.int
    ENCLAVEINFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    """/ The commit id"""
    dcrIdHex: builtins.str
    """/ The DCR hash the commit refers to"""
    driverAttestationHash: builtins.str
    """/ The driver attestation hash"""
    @property
    def enclaveInfo(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EnclaveInfo]:
        """/ Information about the enclaves that were added to the DCR"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        dcrIdHex: builtins.str = ...,
        driverAttestationHash: builtins.str = ...,
        enclaveInfo: collections.abc.Iterable[global___EnclaveInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dcrIdHex", b"dcrIdHex", "driverAttestationHash", b"driverAttestationHash", "enclaveInfo", b"enclaveInfo", "id", b"id"]) -> None: ...

global___MergeDcrCommitRequest = MergeDcrCommitRequest

@typing_extensions.final
class CreateDcrResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CreateDcrResponse = CreateDcrResponse

@typing_extensions.final
class GetOrCreateDatasetScopeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___GetOrCreateDatasetScopeResponse = GetOrCreateDatasetScopeResponse

@typing_extensions.final
class DcrInteractionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DcrInteractionResponse = DcrInteractionResponse

@typing_extensions.final
class CreateDcrCommitResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CreateDcrCommitResponse = CreateDcrCommitResponse

@typing_extensions.final
class MergeDcrCommitResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MergeDcrCommitResponse = MergeDcrCommitResponse

@typing_extensions.final
class StopDcrResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StopDcrResponse = StopDcrResponse

@typing_extensions.final
class PublishDatasetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PublishDatasetResponse = PublishDatasetResponse

@typing_extensions.final
class CreateDatasetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___CreateDatasetResponse = CreateDatasetResponse

@typing_extensions.final
class UnpublishDatasetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UnpublishDatasetResponse = UnpublishDatasetResponse

@typing_extensions.final
class WorkerMetadataRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ATTESTATIONSPEC_FIELD_NUMBER: builtins.int
    SCOPEID_FIELD_NUMBER: builtins.int
    @property
    def attestationSpec(self) -> attestation_pb2.AttestationSpecification:
        """/ Attestation spec of the worker for which to perform the metadata lookup"""
    scopeId: builtins.str
    """/ Id of the scope in the context of which a computation is performed"""
    def __init__(
        self,
        *,
        attestationSpec: attestation_pb2.AttestationSpecification | None = ...,
        scopeId: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["attestationSpec", b"attestationSpec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attestationSpec", b"attestationSpec", "scopeId", b"scopeId"]) -> None: ...

global___WorkerMetadataRequest = WorkerMetadataRequest

@typing_extensions.final
class WorkerMetadataResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAXEXECUTIONSECONDS_FIELD_NUMBER: builtins.int
    maxExecutionSeconds: builtins.int
    def __init__(
        self,
        *,
        maxExecutionSeconds: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["maxExecutionSeconds", b"maxExecutionSeconds"]) -> None: ...

global___WorkerMetadataResponse = WorkerMetadataResponse

@typing_extensions.final
class SubmitWorkerExecutionTimeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTIONTIMESECONDS_FIELD_NUMBER: builtins.int
    ATTESTATIONSPEC_FIELD_NUMBER: builtins.int
    SCOPEID_FIELD_NUMBER: builtins.int
    executionTimeSeconds: builtins.int
    @property
    def attestationSpec(self) -> attestation_pb2.AttestationSpecification: ...
    scopeId: builtins.str
    """/ Id of the scope in the context of which a computation is performed"""
    def __init__(
        self,
        *,
        executionTimeSeconds: builtins.int = ...,
        attestationSpec: attestation_pb2.AttestationSpecification | None = ...,
        scopeId: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["attestationSpec", b"attestationSpec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attestationSpec", b"attestationSpec", "executionTimeSeconds", b"executionTimeSeconds", "scopeId", b"scopeId"]) -> None: ...

global___SubmitWorkerExecutionTimeRequest = SubmitWorkerExecutionTimeRequest

@typing_extensions.final
class SubmitWorkerExecutionTimeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SubmitWorkerExecutionTimeResponse = SubmitWorkerExecutionTimeResponse



from __future__ import annotations

import io
import zipfile
from abc import ABC, abstractmethod
from typing import BinaryIO, Optional

from ..session import Session
from ..storage import Key
from .sql_helper import read_sql_query_result_as_string


class HighLevelNode(ABC):
    """
    Abstract class representing a High Level Node.
    """

    def __init__(
        self,
        name: str,
        id: str,
        dcr_id: str,
        client: Client,
        session: Session,
        definition: NodeDefinition,
    ) -> None:
        super().__init__()
        self.id = id
        self.name = name
        self.dcr_id = dcr_id
        self.client = client
        self.session = session
        self.definition = definition


class ComputationNode(HighLevelNode, ABC):
    """
    Class representing a Computation Node.

    Computation Nodes allow a permitted analyst to run a computation and
    retrieve the results of a computation.
    """

    def __init__(
        self,
        id: str,
        name: str,
        dcr_id: str,
        session: Session,
        definition: NodeDefinition,
        *,
        client: Client,
    ) -> None:
        """
        Initialise an instance of a `ComputationNode`.

        **Parameters**:
        - `name`: Name of the `ComputationNode`.
        - `dcr_id`: ID of the DCR the node is a member of.
        - `session`: The session with which to communicate with the enclave.
        - 'definition': Definition with which the node was built.
        - `client`: A `Client` object which can be used to perform operations such as uploading data
            and retrieving computation results.
        - 'id': Node ID.
        """
        super().__init__(
            name=name,
            client=client,
            session=session,
            dcr_id=dcr_id,
            id=id,
            definition=definition,
        )
        self.job_id = None

    def run_computation(self):
        """
        Run the computation associated with this node.
        """
        if not self.session:
            raise Exception(
                f"Unable to run computation. Node {self.id} does not have an associated session"
            )
        self.job_id = self.session.run_computation(
            self.dcr_id, self._get_computation_id()
        )

    def get_results_as_bytes(
        self,
        interval: int = 5,
        timeout: Optional[int] = None,
    ) -> Optional[bytes]:
        """
        Retrieve the results of a computation.

        **Parameters**:
        - `interval`: Time interval (in seconds) to check for results.
        - `timeout`: Time (in seconds) after which results are no longer checked.
        """
        if not self.job_id:
            raise Exception("A computation must be run before results can be retrieved")
        return self.session.get_computation_result(
            self.job_id, interval=interval, timeout=timeout
        )

    def run_computation_and_get_results_as_bytes(
        self,
        interval: int = 5,
        timeout: Optional[int] = None,
    ):
        """
        This is a blocking call to run a computation and get the results.

        **Parameters**:
        - `interval`: Time interval (in seconds) to check for results.
        - `timeout`: Time (in seconds) after which results are no longer checked.
        """
        if not self.session:
            raise Exception(
                f"Unable to run computation. Node {self.id} does not have an associated session"
            )
        return self.session.run_computation_and_get_results(
            self.dcr_id,
            self._get_computation_id(),
            interval=interval,
            timeout=timeout,
        )

    @abstractmethod
    def _get_computation_id(self) -> str:
        """
        Retrieve the ID of the node corresponding to the computation.
        """
        pass


class ContainerComputationNode(ComputationNode):
    def __init__(
        self,
        *args,
        **kwargs,
    ) -> None:
        super().__init__(*args, **kwargs)

    def get_results_as_zip(
        self,
        interval: int = 5,
        timeout: Optional[int] = None,
    ) -> Optional[zipfile.ZipFile]:
        """
        Retrieve the results of a computation as a ZIP file.

        **Parameters**:
        - `interval`: Time interval (in seconds) to check for results.
        - `timeout`: Time (in seconds) after which results are no longer checked.
        """
        raw_result = self.get_results_as_bytes(interval=interval, timeout=timeout)
        if raw_result:
            return zipfile.ZipFile(io.BytesIO(raw_result), "r")
        else:
            return None

    def run_computation_and_get_results_as_zip(
        self,
        interval: int = 5,
        timeout: Optional[int] = None,
    ):
        """
        This is a blocking call to run a computation and get the results as a ZIP file.

        **Parameters**:
        - `interval`: Time interval (in seconds) to check for results.
        - `timeout`: Time (in seconds) after which results are no longer checked.
        """
        raw_result = self.run_computation_and_get_results_as_bytes(
            interval=interval, timeout=timeout
        )
        if raw_result:
            return zipfile.ZipFile(io.BytesIO(raw_result), "r")
        else:
            return None


class StructuredOutputNode(ComputationNode):
    def __init__(
        self,
        *args,
        **kwargs,
    ) -> None:
        super().__init__(*args, **kwargs)

    def get_results_as_string(
        self,
        interval: int = 5,
        timeout: Optional[int] = None,
    ) -> Optional[str]:
        """
        Retrieve the results of a computation as a string.

        **Parameters**:
        - `interval`: Time interval (in seconds) to check for results.
        - `timeout`: Time (in seconds) after which results are no longer checked.
        """
        raw_result = self.get_results_as_bytes(interval=interval, timeout=timeout)
        if raw_result:
            return read_sql_query_result_as_string(raw_result)
        else:
            return None

    def run_computation_and_get_results_as_string(
        self,
        interval: int = 5,
        timeout: Optional[int] = None,
    ) -> Optional[str]:
        """
        This is a blocking call to run a computation and get the results as a
        string.

        **Parameters**:
        - `interval`: Time interval (in seconds) to check for results.
        - `timeout`: Time (in seconds) after which results are no longer checked.
        """
        raw_result = self.run_computation_and_get_results_as_bytes(
            interval=interval, timeout=timeout
        )
        if raw_result:
            return read_sql_query_result_as_string(raw_result)
        else:
            return None


class DataNode(HighLevelNode, ABC):
    """
    Class representing a Data node.

    Data nodes allow a permitted data owner to upload and publish dataset to the node.
    """

    def __init__(
        self,
        name: str,
        id: str,
        dcr_id: str,
        is_required: bool,
        session: Session,
        definition: NodeDefinition,
        *,
        client: Client,
    ) -> None:
        """
        Initialise an instance of a `DataNode`.

        **Parameters**:
        - `name`: Name of the `DataNode`.
        - `dcr_id`: ID of the DCR the node is a member of.
        - `is_required`: Flag determining if the `DataNode` must be present for dependent computations.
        - `session`: The session with which to communicate with the enclave.
        - `id`: ID of the `DataNode`.
        - 'definition': Definition with which the node was built.
        - `client`: A `Client` object which can be used to perform operations such as uploading data
            and retrieving computation results.
        """
        super().__init__(
            name=name,
            dcr_id=dcr_id,
            client=client,
            session=session,
            id=id,
            definition=definition,
        )
        self.is_required = is_required

    def publish_dataset(self, manifest_hash: str, key: Key):
        """
        Publish data to the `DataNode`.

        **Parameters**:
        - `manifest_hash`: Hash identifying the dataset to be published.
        - `key`: Encryption key used to decrypt the dataset.
        """
        self.session.publish_dataset(
            self.dcr_id, manifest_hash, leaf_id=self.id, key=key
        )

    def upload_and_publish_dataset(
        self,
        data: BinaryIO,
        key: Key,
        name: str,
        store_in_keychain: Optional[Keychain] = None,
        description: str = "",
    ):
        """
        Upload data to the Decentriq Platform and publish it to the `DataNode`.

        **Parameters**:
        - `data`: Binary representation of the data to be uploaded.
        - `key`: Key to be used for encrypting the data.
        - `name`: Name of the file.
        - `store_in_keychain`: An optional keychain in which to store the dataset key.
        - `description`: An optional description of the dataset.
        """
        if not self.dcr_id:
            raise Exception("Data node is not part of a data room")

        manifest_hash = self.client.upload_dataset(
            data,
            key,
            name,
            store_in_keychain=store_in_keychain,
            description=description,
        )
        self.publish_dataset(manifest_hash, key)

    def remove_published_dataset(self) -> None:
        """
        Removes any dataset that is published to this node.
        """
        self.session.remove_published_dataset(self.dcr_id, self.id)



from __future__ import annotations

from decentriq_dcr_compiler.schemas.data_science_data_room import (
    MatchingComputationNode,
)
from .high_level_node import ContainerComputationNode
from typing import Dict, List, Optional
from .node_definitions import NodeDefinition
from ..session import Session
from dataclasses import dataclass, asdict
from typing_extensions import Self
import json


@dataclass
class MatchingComputeNodeConfig:
    query: List[str]
    round: int
    epsilon: int
    sensitivity: int
    dependency_paths: List[str]


class MatchingComputeNodeDefinition(NodeDefinition):
    """
    Class definining the structure of a MatchingComputeNode.

    A MatchingComputeNode can be used to join two datasets based on common
    columns.
    """

    def __init__(
        self,
        name: str,
        config: MatchingComputeNodeConfig,
        dependencies: List[str],
        enable_logs_on_error: bool = False,
        enable_logs_on_success: bool = False,
        output: Optional[str] = "/output",
        id: Optional[str] = None,
    ) -> None:
        """
        Initialise a `MatchingComputeNodeDefinition`:

        **Parameters**:
        `name`: Name of the `MatchingComputeNodeDefinition`.
        `config`: Configuration of the `MatchingComputeNodeDefinition`.
        `dependencies`: Nodes that the `MatchingComputeNodeDefinition` depends on.
        `enable_logs_on_error`: Enable logs in the event of an error.
        `enable_logs_on_success`: Enable logs when the computation is successful.
        `output`: Directory where the results will be written.
        """
        super().__init__(name=name, id=id or name)
        self.config = config
        self.dependencies = dependencies
        self.enable_logs_on_error = enable_logs_on_error
        self.enable_logs_on_success = enable_logs_on_success
        self.output = output
        self.specification_id = "decentriq.python-ml-worker-32-64"
        self.static_content_specification_id = "decentriq.driver"

    @property
    def required_workers(self):
        return [self.specification_id, self.static_content_specification_id]

    def _get_high_level_representation(self) -> Dict[str, str]:
        """
        Retrieve the high level representation of the `MatchingComputeNodeDefinition`.
        """
        dependencies = [] if not self.dependencies else self.dependencies
        computation_node = {
            "id": self.id,
            "name": self.name,
            "kind": {
                "computation": {
                    "kind": {
                        "match": {
                            "config": json.dumps(asdict(self.config)),
                            "dependencies": dependencies,
                            "enableLogsOnError": self.enable_logs_on_error,
                            "enableLogsOnSuccess": self.enable_logs_on_success,
                            "output": self.output,
                            "specificationId": self.specification_id,
                            "staticContentSpecificationId": self.static_content_specification_id,
                        }
                    }
                },
            },
        }
        return computation_node

    @staticmethod
    def _from_high_level(id: str, name: str, node: MatchingComputationNode) -> Self:
        """
        Instantiate a `MatchingComputeNode` from its high level representation.

        **Parameters**:
        - `name`: Name of the `MatchingComputeNode`.
        - `node`: Pydantic model of the `MatchingComputeNode`.
        """
        matching_node = json.loads(node.model_dump_json())
        return MatchingComputeNodeDefinition(
            name=name,
            config=json.loads(matching_node["config"]),
            dependencies=matching_node["dependencies"],
            enable_logs_on_error=matching_node["enableLogsOnError"],
            enable_logs_on_success=matching_node["enableLogsOnSuccess"],
            output=matching_node["output"],
            id=id,
        )

    def build(
        self,
        dcr_id: str,
        node_definition: NodeDefinition,
        client: Client,
        session: Session,
    ) -> MatchingComputeNode:
        """
        Construct a MatchingComputeNode from the Node Definition.

        **Parameters**:
        - `dcr_id`: ID of the DCR the node is a member of.
        - `node_definition`: Definition of the Matching Node.
        - `client`: A `Client` object which can be used to perform operations such as uploading data
            and retrieving computation results.
        - `session`: The session with which to communicate with the enclave.
        """
        return MatchingComputeNode(
            name=self.name,
            dcr_id=dcr_id,
            config=self.config,
            dependencies=self.dependencies,
            client=client,
            session=session,
            node_definition=node_definition,
            enable_logs_on_error=self.enable_logs_on_error,
            enable_logs_on_success=self.enable_logs_on_success,
            id=self.id,
        )


class MatchingComputeNode(ContainerComputationNode):
    """
    Class representing a Matching Compute Node.

    A MatchingComputeNode can be used to join two datasets based on common
    columns.
    """

    def __init__(
        self,
        id: str,
        name: str,
        dcr_id: str,
        config: MatchingComputeNodeConfig,
        dependencies: List[str],
        client: Client,
        session: Session,
        node_definition: NodeDefinition,
        enable_logs_on_error: bool = False,
        enable_logs_on_success: bool = False,
        output: Optional[str] = "/output",
    ) -> None:
        """
        Initialise a `MatchingComputeNode`:

        **Parameters**:
        - `name`: Name of the `MatchingComputeNode`.
        - `dcr_id`: ID of the DCR this node is part of.
        - `config`: Configuration of the `MatchingComputeNode`.
        - `dependencies`: Nodes that the `MatchingComputeNode` depends on.
        - `client`: A `Client` object which can be used to perform operations such as uploading data
            and retrieving computation results.
        - `session`: The session with which to communicate with the enclave.
        - `node_definition`: Definition with which this node was built.
        `enable_logs_on_error`: Enable logs in the event of an error.
        `enable_logs_on_success`: Enable logs when the computation is successful.
        `output`: Directory where the results will be written.
        `id`: Optional ID of the `MatchingComputeNode`.
        """
        super().__init__(
            name=name,
            client=client,
            session=session,
            dcr_id=dcr_id,
            id=id,
            definition=node_definition,
        )
        self.config = config
        self.dependencies = dependencies
        self.enable_logs_on_error = enable_logs_on_error
        self.enable_logs_on_success = enable_logs_on_success
        self.output = output
        self.specification_id = "decentriq.python-ml-worker-32-64"
        self.static_content_specification_id = "decentriq.driver"

    def _get_computation_id(self) -> str:
        """
        Retrieve the ID of the node corresponding to the computation.
        """
        return f"{self.id}_match_filter_node"



from __future__ import annotations

import json
from ..proto import serialize_length_delimited
from typing import Dict, List, Tuple, Union, Optional
from ..session import Session
from dataclasses import dataclass
from decentriq_dcr_compiler import (
    upgrade_data_science_data_room_to_latest,
    verify_data_room,
)
from decentriq_dcr_compiler.schemas.data_science_commit import DataScienceCommitV6
from decentriq_dcr_compiler.schemas.data_science_data_room import (
    DataScienceDataRoom,
    DataScienceDataRoomConfigurationV6,
    LeafNodeV2,
    ComputationNodeV6,
    ScriptingLanguage,
    Participant,
)
from .node_definitions import NodeDefinition
from .python_compute_nodes import PythonComputeNodeDefinition
from .r_compute_nodes import RComputeNodeDefinition
from .sql_compute_nodes import SqlComputeNodeDefinition
from .sqlite_compute_nodes import SqliteComputeNodeDefinition
from .s3_sink_compute_nodes import S3SinkComputeNodeDefinition
from .matching_compute_nodes import MatchingComputeNodeDefinition
from .synthetic_compute_nodes import SyntheticDataComputeNodeDefinition
from .preview_compute_nodes import PreviewComputeNodeDefinition
from .raw_data_nodes import RawDataNodeDefinition
from .table_data_nodes import TableDataNodeDefinition
from .version import DATA_SCIENCE_DCR_SUPPORTED_VERSION


@dataclass
class ExistingConfiguration:
    name: str
    description: str
    owner: Optional[str]
    node_definitions: List
    dcr_id: str
    enable_development: bool
    enable_airlock: bool
    participants: List
    enable_auto_merge_feature: bool


class ExistingAnalyticsDcrBuilder:
    """
    Builder for retrieving configuration information from an existing Analytics Data Clean Room.
    """

    def __init__(self, dcr_id: str, client: Client, session: Session) -> None:
        self.dcr_id = dcr_id
        self.client = client
        self.session = session
        self.high_level = None
        existing_dcr = self.session.retrieve_data_room(self.dcr_id)
        self.high_level = json.loads(existing_dcr.highLevelRepresentation.decode())

    def get_configuration(self) -> ExistingConfiguration:
        """
        Retrieve the configuration information for the existing Analytics Data Clean Room.
        """
        dcr_config, commits, enable_auto_merge_feature = self._get_data_room()
        model_participants = self._get_participants(dcr_config)
        participants = [participant.user for participant in model_participants]
        owner = self._get_owner(model_participants)
        node_definitions = self._get_nodes(dcr_config, commits)

        enable_development = dcr_config.enableDevelopment
        enable_airlock = dcr_config.enableAirlock
        name = dcr_config.title
        description = dcr_config.description

        return ExistingConfiguration(
            name,
            description,
            owner,
            node_definitions,
            self.dcr_id,
            enable_development,
            enable_airlock,
            participants,
            enable_auto_merge_feature,
        )

    def _get_data_room(
        self,
    ) -> Tuple[(DataScienceDataRoomConfigurationV6, List[DataScienceCommitV6], bool)]:
        # Verify that the LL and HL match
        existing_dcr = self.session.retrieve_data_room(self.dcr_id)
        existing_dcr.highLevelRepresentation.decode()
        verify_data_room(
            serialize_length_delimited(existing_dcr.dataRoom),
            [serialize_length_delimited(c) for c in existing_dcr.commits],
            existing_dcr.highLevelRepresentation,
        )
        # HL was verified, continue parsing the HL
        high_level = DataScienceDataRoom.model_validate(self.high_level)
        latest_high_level = upgrade_data_science_data_room_to_latest(high_level)
        if not hasattr(latest_high_level.root, DATA_SCIENCE_DCR_SUPPORTED_VERSION):
            raise Exception(
                "The retrieved DCR was upgraded to the latest known version,"
                " but it differs from the latest supported version in this SDK"
                f" ({DATA_SCIENCE_DCR_SUPPORTED_VERSION})."
                " This very likely means that your SDK version is out of date and needs to be"
                " upgraded to the latest version."
            )
        else:
            dcr = getattr(
                latest_high_level.root, DATA_SCIENCE_DCR_SUPPORTED_VERSION
            ).root
            if hasattr(dcr, "interactive"):
                return (
                    dcr.interactive.initialConfiguration,
                    dcr.interactive.commits,
                    dcr.interactive.enableAutomergeFeature,
                )
            elif hasattr(dcr, "static"):
                return (dcr.static, [], False)
            else:
                raise Exception("Expected DCR to be either static or interactive")

    def _get_participants(
        self, config: DataScienceDataRoomConfigurationV6
    ) -> List[Participant]:
        participants = [participant for participant in config.participants]
        return participants

    def _get_nodes(
        self,
        config: DataScienceDataRoomConfigurationV6,
        commits: List[DataDataScienceDataRoomCommitV6],
    ) -> List[NodeDefinition]:
        nodes = []
        hl_nodes = config.nodes
        # Add any node that might have been added via a commit in the UI
        for commit in commits:
            if hasattr(commit.kind, "addComputation"):
                hl_nodes.append(commit.kind.addComputation.node)

        for node in hl_nodes:
            name = node.name
            root_node = node.kind.root
            node_fields = root_node.model_fields

            if "computation" in node_fields:
                computation_node = (
                    self._construct_computation_node_from_hl_representation(
                        node.id, name, node.kind.root.computation
                    )
                )
                nodes.append(computation_node)
            elif "leaf" in node_fields:
                data_node = self._construct_data_node_from_hl_representation(
                    node.id,
                    name,
                    node.kind.root.leaf,
                )
                nodes.append(data_node)
            else:
                raise Exception("Unknown node type")
        return nodes

    def _construct_computation_node_from_hl_representation(
        self,
        id: str,
        name: str,
        node: ComputationNodeV6,
    ) -> Union[
        PythonComputeNodeDefinition,
        RComputeNodeDefinition,
        SqlComputeNodeDefinition,
        SqliteComputeNodeDefinition,
        S3SinkComputeNodeDefinition,
        MatchingComputeNodeDefinition,
        SyntheticDataComputeNodeDefinition,
        PreviewComputeNodeDefinition,
    ]:
        root_node = node.kind.root
        node_fields = root_node.model_fields
        compute_node_definition = None
        if "scripting" in node_fields:
            parsed_node = root_node.scripting
            if parsed_node.scriptingLanguage.value == ScriptingLanguage.python.value:
                compute_node_definition = PythonComputeNodeDefinition._from_high_level(
                    id, name, parsed_node
                )
            elif parsed_node.scriptingLanguage.value == ScriptingLanguage.r.value:
                compute_node_definition = RComputeNodeDefinition._from_high_level(
                    id, name, parsed_node
                )
            else:
                raise Exception(
                    f"Unknown scripting language {parsed_node.scriptingLanguage}"
                )
        elif "sql" in node_fields:
            compute_node_definition = SqlComputeNodeDefinition._from_high_level(
                id, name, root_node.sql
            )
        elif "sqlite" in node_fields:
            compute_node_definition = SqliteComputeNodeDefinition._from_high_level(
                id, name, root_node.sqlite
            )
        elif "s3Sink" in node_fields:
            compute_node_definition = S3SinkComputeNodeDefinition._from_high_level(
                id, name, root_node.s3Sink
            )
        elif "match" in node_fields:
            compute_node_definition = MatchingComputeNodeDefinition._from_high_level(
                id, name, root_node.match
            )
        elif "syntheticData" in node_fields:
            compute_node_definition = (
                SyntheticDataComputeNodeDefinition._from_high_level(
                    id, name, root_node.syntheticData
                )
            )
        elif "preview" in node_fields:
            compute_node_definition = PreviewComputeNodeDefinition._from_high_level(
                id, name, root_node.preview
            )
        else:
            raise Exception("Unknown computation node type")
        return compute_node_definition

    def _construct_data_node_from_hl_representation(
        self,
        id: str,
        name: str,
        node: LeafNodeV2,
    ) -> Union[RawDataNodeDefinition, TableDataNodeDefinition]:
        is_required = node.isRequired
        root_node = node.kind.root
        node_fields = root_node.model_fields
        data_node = None
        if "raw" in node_fields:
            data_node = RawDataNodeDefinition._from_high_level(
                id, name, root_node.raw, is_required
            )
        elif "table" in node_fields:
            data_node = TableDataNodeDefinition._from_high_level(
                id,
                name,
                root_node.table,
                is_required,
            )
        else:
            raise Exception("Unknown data node type")
        data_node.dcr_id = self.dcr_id
        data_node.session = self.session
        data_node.client = self.client
        return data_node

    @staticmethod
    def _get_node_permissions_dict(
        participants: List[Participant],
    ) -> Tuple[Dict[str, List[str]], Dict[str, List[str]]]:
        node_data_permissions = {}
        node_compute_permissions = {}
        for participant in participants:
            user = participant.user
            for permission in participant.permissions:
                root_permission = permission.root
                permission_fields = root_permission.model_fields
                if "dataOwner" in permission_fields:
                    data_owner = root_permission.dataOwner
                    node_id = data_owner.nodeId
                    users = node_data_permissions.setdefault(data_owner.nodeId, [])
                    users.append(user)
                    node_data_permissions[node_id] = users
                elif "analyst" in permission_fields:
                    analyst = root_permission.analyst
                    node_id = analyst.nodeId
                    users = node_data_permissions.setdefault(node_id, [])
                    users.append(user)
                    node_compute_permissions[node_id] = users
        return (node_compute_permissions, node_data_permissions)

    @staticmethod
    def _get_owner(
        participants: List[Participant],
    ) -> Optional[str]:
        for participant in participants:
            user = participant.user
            for permission in participant.permissions:
                root_permission = permission.root
                permission_fields = root_permission.model_fields
                if "manager" in permission_fields:
                    return user



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class RawFile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RawFile = RawFile

@typing_extensions.final
class AllFiles(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___AllFiles = AllFiles

@typing_extensions.final
class SingleFile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    RENAMEAS_FIELD_NUMBER: builtins.int
    name: builtins.str
    renameAs: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        renameAs: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_renameAs", b"_renameAs", "renameAs", b"renameAs"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_renameAs", b"_renameAs", "name", b"name", "renameAs", b"renameAs"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_renameAs", b"_renameAs"]) -> typing_extensions.Literal["renameAs"] | None: ...

global___SingleFile = SingleFile

@typing_extensions.final
class FileSelection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMES_FIELD_NUMBER: builtins.int
    @property
    def names(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SingleFile]: ...
    def __init__(
        self,
        *,
        names: collections.abc.Iterable[global___SingleFile] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["names", b"names"]) -> None: ...

global___FileSelection = FileSelection

@typing_extensions.final
class ZipFile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALL_FIELD_NUMBER: builtins.int
    FILES_FIELD_NUMBER: builtins.int
    @property
    def all(self) -> global___AllFiles: ...
    @property
    def files(self) -> global___FileSelection: ...
    def __init__(
        self,
        *,
        all: global___AllFiles | None = ...,
        files: global___FileSelection | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["all", b"all", "files", b"files", "selection", b"selection"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["all", b"all", "files", b"files", "selection", b"selection"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["selection", b"selection"]) -> typing_extensions.Literal["all", "files"] | None: ...

global___ZipFile = ZipFile

@typing_extensions.final
class SinkInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPENDENCY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RAW_FIELD_NUMBER: builtins.int
    ZIP_FIELD_NUMBER: builtins.int
    dependency: builtins.str
    name: builtins.str
    @property
    def raw(self) -> global___RawFile: ...
    @property
    def zip(self) -> global___ZipFile: ...
    def __init__(
        self,
        *,
        dependency: builtins.str = ...,
        name: builtins.str = ...,
        raw: global___RawFile | None = ...,
        zip: global___ZipFile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["file", b"file", "raw", b"raw", "zip", b"zip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dependency", b"dependency", "file", b"file", "name", b"name", "raw", b"raw", "zip", b"zip"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["file", b"file"]) -> typing_extensions.Literal["raw", "zip"] | None: ...

global___SinkInput = SinkInput

@typing_extensions.final
class DatasetSinkWorkerConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INPUTS_FIELD_NUMBER: builtins.int
    ENCRYPTIONKEYDEPENDENCY_FIELD_NUMBER: builtins.int
    DATASETIMPORTID_FIELD_NUMBER: builtins.int
    ISKEYHEXENCODED_FIELD_NUMBER: builtins.int
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SinkInput]: ...
    encryptionKeyDependency: builtins.str
    """The id of the leaf node that contains the encryption key"""
    datasetImportId: builtins.str
    isKeyHexEncoded: builtins.bool
    """Whether the key provided in `encryptionKeyDependency` is hex encoded or binary"""
    def __init__(
        self,
        *,
        inputs: collections.abc.Iterable[global___SinkInput] | None = ...,
        encryptionKeyDependency: builtins.str = ...,
        datasetImportId: builtins.str | None = ...,
        isKeyHexEncoded: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_datasetImportId", b"_datasetImportId", "datasetImportId", b"datasetImportId"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_datasetImportId", b"_datasetImportId", "datasetImportId", b"datasetImportId", "encryptionKeyDependency", b"encryptionKeyDependency", "inputs", b"inputs", "isKeyHexEncoded", b"isKeyHexEncoded"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_datasetImportId", b"_datasetImportId"]) -> typing_extensions.Literal["datasetImportId"] | None: ...

global___DatasetSinkWorkerConfiguration = DatasetSinkWorkerConfiguration



from __future__ import annotations
from google.protobuf.json_format import MessageToDict
from .proto import PostWorkerConfiguration
from ...proto import (
    serialize_length_delimited,
    ComputeNodeFormat,
    parse_length_delimited,
)
from ..node import Node


__all__ = ["PostCompute"]


class PostWorkerDecoder:
    def decode(config: bytes):
        config_decoded = PostWorkerConfiguration()
        parse_length_delimited(config, config_decoded)
        return MessageToDict(config_decoded)


class PostCompute(Node):
    """
    Computation node which makes a secure API call to the Post Address
    Maintainance Service to the check the input addresses
    """

    def __init__(
        self, name: str, dependency: str, use_mock_backend: bool = False
    ) -> None:
        configuration = PostWorkerConfiguration()
        configuration.useMockBackend = use_mock_backend
        config = serialize_length_delimited(configuration)

        super().__init__(
            name,
            config,
            enclave_type="decentriq.post-worker",
            dependencies=[dependency],
            output_format=ComputeNodeFormat.ZIP,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google_ad_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17google_ad_manager.proto\x12\x11google_ad_manager\"\x1a\n\nSingleFile\x12\x0c\n\x04name\x18\x01 \x01(\t\"\t\n\x07RawFile\"K\n\x07ZipFile\x12\x33\n\nsingleFile\x18\x01 \x01(\x0b\x32\x1d.google_ad_manager.SingleFileH\x00\x42\x0b\n\tselection\"\x8b\x01\n\tSinkInput\x12\x12\n\ndependency\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12)\n\x03raw\x18\x03 \x01(\x0b\x32\x1a.google_ad_manager.RawFileH\x00\x12)\n\x03zip\x18\x04 \x01(\x0b\x32\x1a.google_ad_manager.ZipFileH\x00\x42\x06\n\x04\x66ile\"\xd5\x01\n\"GoogleAdManagerWorkerConfiguration\x12+\n\x05input\x18\x01 \x01(\x0b\x32\x1c.google_ad_manager.SinkInput\x12\x1d\n\x15\x63redentialsDependency\x18\x02 \x01(\t\x12\x16\n\x0eidentifierKind\x18\x03 \x01(\t\x12\x0e\n\x06listId\x18\x04 \x01(\t\x12\x17\n\x0finputHasHeaders\x18\x05 \x01(\x08\x12\x0e\n\x06\x62ucket\x18\x06 \x01(\t\x12\x12\n\nobjectName\x18\x07 \x01(\tb\x06proto3')



_SINGLEFILE = DESCRIPTOR.message_types_by_name['SingleFile']
_RAWFILE = DESCRIPTOR.message_types_by_name['RawFile']
_ZIPFILE = DESCRIPTOR.message_types_by_name['ZipFile']
_SINKINPUT = DESCRIPTOR.message_types_by_name['SinkInput']
_GOOGLEADMANAGERWORKERCONFIGURATION = DESCRIPTOR.message_types_by_name['GoogleAdManagerWorkerConfiguration']
SingleFile = _reflection.GeneratedProtocolMessageType('SingleFile', (_message.Message,), {
  'DESCRIPTOR' : _SINGLEFILE,
  '__module__' : 'google_ad_manager_pb2'
  # @@protoc_insertion_point(class_scope:google_ad_manager.SingleFile)
  })
_sym_db.RegisterMessage(SingleFile)

RawFile = _reflection.GeneratedProtocolMessageType('RawFile', (_message.Message,), {
  'DESCRIPTOR' : _RAWFILE,
  '__module__' : 'google_ad_manager_pb2'
  # @@protoc_insertion_point(class_scope:google_ad_manager.RawFile)
  })
_sym_db.RegisterMessage(RawFile)

ZipFile = _reflection.GeneratedProtocolMessageType('ZipFile', (_message.Message,), {
  'DESCRIPTOR' : _ZIPFILE,
  '__module__' : 'google_ad_manager_pb2'
  # @@protoc_insertion_point(class_scope:google_ad_manager.ZipFile)
  })
_sym_db.RegisterMessage(ZipFile)

SinkInput = _reflection.GeneratedProtocolMessageType('SinkInput', (_message.Message,), {
  'DESCRIPTOR' : _SINKINPUT,
  '__module__' : 'google_ad_manager_pb2'
  # @@protoc_insertion_point(class_scope:google_ad_manager.SinkInput)
  })
_sym_db.RegisterMessage(SinkInput)

GoogleAdManagerWorkerConfiguration = _reflection.GeneratedProtocolMessageType('GoogleAdManagerWorkerConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _GOOGLEADMANAGERWORKERCONFIGURATION,
  '__module__' : 'google_ad_manager_pb2'
  # @@protoc_insertion_point(class_scope:google_ad_manager.GoogleAdManagerWorkerConfiguration)
  })
_sym_db.RegisterMessage(GoogleAdManagerWorkerConfiguration)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SINGLEFILE._serialized_start=46
  _SINGLEFILE._serialized_end=72
  _RAWFILE._serialized_start=74
  _RAWFILE._serialized_end=83
  _ZIPFILE._serialized_start=85
  _ZIPFILE._serialized_end=160
  _SINKINPUT._serialized_start=163
  _SINKINPUT._serialized_end=302
  _GOOGLEADMANAGERWORKERCONFIGURATION._serialized_start=305
  _GOOGLEADMANAGERWORKERCONFIGURATION._serialized_end=518
# @@protoc_insertion_point(module_scope)



from ..client import Client
from ..types import MatchingId
from . import DataLab, DataLabConfig, ExistingDataLab
from ..keychain import Keychain


class DataLabBuilder:
    """
    A helper class to build a Data Lab.
    """

    def __init__(
        self,
        client: Client,
    ):
        self.name = None
        self.has_demographics = False
        self.has_embeddings = False
        self.num_embeddings = 0
        self.matching_id = MatchingId.STRING
        self.validation_id = None
        self.client = client
        self.existing = False
        self.data_lab_id = None

    def with_name(self, name: str):
        """
        Set the name of the DataLab.

        **Parameters**:
        - `name`: Name to be used for the DataLab.
        """
        self.name = name

    def with_matching_id_format(self, matching_id: MatchingId):
        """
        Set the matching ID format.

        **Parameters**:
        - `matching_id`: The type of matching ID to use.
        """
        self.matching_id = matching_id

    def with_demographics(self):
        """
        Enable demographics in the DataLab.
        """
        self.has_demographics = True

    def with_embeddings(self, num_embeddings: int):
        """
        Enable embeddings in the DataLab.

        **Parameters**:
        - `num_embeddings`: The number of embeddings the DataLab should use.
        """
        self.has_embeddings = True
        self.num_embeddings = num_embeddings

    def from_existing(self, data_lab_id: str, keychain: Keychain):
        """
        Construct a new DataLab from an existing DataLab with the given ID.

        **Parameters**:
        - `data_lab_id`: The ID of the existing DataLab.
        - `keychain`: The keychain to use to provision datasets from the old DataLab to the new DataLab.
        """
        self.existing = True
        self.data_lab_id = data_lab_id
        self.keychain = keychain

    def build(self) -> DataLab:
        """
        Build the DataLab.
        """
        if self.existing:
            # Build a new DataLab from an existing one.
            # The new DataLab will have the same configuration as the existing one.
            data_lab_definition = self.client.get_data_lab(self.data_lab_id)
            cfg = DataLabConfig(
                data_lab_definition["name"],
                data_lab_definition["requireDemographicsDataset"],
                data_lab_definition["requireEmbeddingsDataset"],
                data_lab_definition["numEmbeddings"],
                data_lab_definition["matchingIdFormat"],
            )
            existing_data_lab = ExistingDataLab(data_lab_definition, self.keychain)
            return DataLab(self.client, cfg, existing_data_lab)
        else:
            # Build a new DataLab using the specified enclave specifications.
            cfg = DataLabConfig(
                self.name,
                self.has_demographics,
                self.has_embeddings,
                self.num_embeddings,
                self.matching_id,
            )
            return DataLab(self.client, cfg)



from google.protobuf.json_format import MessageToDict
from ...proto import (
    serialize_length_delimited,
    ComputeNodeFormat,
    parse_length_delimited,
)
from ..node import Node
from .proto import (
    PermutiveWorkerConfiguration,
    SinkInput,
    ExportRole,
)


class DataSourcePermutive(Node):
    """
    Compute node that fetches a dataset from Permutive.
    """

    def __init__(
        self,
        name: str,
        credentials_dependency: str,
    ) -> None:
        config = PermutiveWorkerConfiguration(
            credentialsDependency=credentials_dependency, importRole={}
        )
        config_serialized = serialize_length_delimited(config)
        super().__init__(
            name,
            config=config_serialized,
            enclave_type="decentriq.permutive-worker",
            dependencies=[credentials_dependency],
            output_format=ComputeNodeFormat.RAW,
        )


class PermutiveDataTransformer(Node):
    """
    Compute node that transforms data into a Permutive compliant form.
    """

    def __init__(
        self,
        name: str,
        credentials_dependency: str,
        input: SinkInput,
        import_id: str,
        segment_name: str,
        segment_code: str,
        input_has_headers: bool,
    ) -> None:
        config = PermutiveWorkerConfiguration(
            credentialsDependency=credentials_dependency,
            exportRole=ExportRole(input=input),
            importId=import_id,
            segmentName=segment_name,
            segmentCode=segment_code,
            inputHasHeaders=input_has_headers,
        )
        config_serialized = serialize_length_delimited(config)
        super().__init__(
            name,
            config=config_serialized,
            enclave_type="decentriq.permutive-worker",
            dependencies=[credentials_dependency, input.dependency],
            output_format=ComputeNodeFormat.RAW,
        )


class PermutiveWorkerDecoder:
    def decode(self, config: bytes):
        config_decoded = PermutiveWorkerConfiguration()
        parse_length_delimited(config, config_decoded)
        return MessageToDict(config_decoded)


__all__ = ["DataSourcePermutive", "PermutiveDataTransformer", "PermutiveWorkerDecoder"]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: data_source_s3.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x64\x61ta_source_s3.proto\x12\x0e\x64\x61ta_source_s3\"=\n\x08S3Source\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0e\n\x06region\x18\x02 \x01(\t\x12\x11\n\tobjectKey\x18\x03 \x01(\t\"\x9a\x01\n\x1f\x44\x61taSourceS3WorkerConfiguration\x12(\n\x06source\x18\x01 \x01(\x0b\x32\x18.data_source_s3.S3Source\x12\x1d\n\x15\x63redentialsDependency\x18\x02 \x01(\t\x12.\n\ns3Provider\x18\x03 \x01(\x0e\x32\x1a.data_source_s3.S3Provider*\x1e\n\nS3Provider\x12\x07\n\x03\x41WS\x10\x00\x12\x07\n\x03GCS\x10\x01\x62\x06proto3')

_S3PROVIDER = DESCRIPTOR.enum_types_by_name['S3Provider']
S3Provider = enum_type_wrapper.EnumTypeWrapper(_S3PROVIDER)
AWS = 0
GCS = 1


_S3SOURCE = DESCRIPTOR.message_types_by_name['S3Source']
_DATASOURCES3WORKERCONFIGURATION = DESCRIPTOR.message_types_by_name['DataSourceS3WorkerConfiguration']
S3Source = _reflection.GeneratedProtocolMessageType('S3Source', (_message.Message,), {
  'DESCRIPTOR' : _S3SOURCE,
  '__module__' : 'data_source_s3_pb2'
  # @@protoc_insertion_point(class_scope:data_source_s3.S3Source)
  })
_sym_db.RegisterMessage(S3Source)

DataSourceS3WorkerConfiguration = _reflection.GeneratedProtocolMessageType('DataSourceS3WorkerConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCES3WORKERCONFIGURATION,
  '__module__' : 'data_source_s3_pb2'
  # @@protoc_insertion_point(class_scope:data_source_s3.DataSourceS3WorkerConfiguration)
  })
_sym_db.RegisterMessage(DataSourceS3WorkerConfiguration)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _S3PROVIDER._serialized_start=260
  _S3PROVIDER._serialized_end=290
  _S3SOURCE._serialized_start=40
  _S3SOURCE._serialized_end=101
  _DATASOURCES3WORKERCONFIGURATION._serialized_start=104
  _DATASOURCES3WORKERCONFIGURATION._serialized_end=258
# @@protoc_insertion_point(module_scope)



from __future__ import annotations

from enum import Enum
import io, json
from typing import Dict, Optional, List
import zipfile
from .high_level_node import DataNode
from ..session import Session
from dataclasses import dataclass
from ..storage import Key
from decentriq_dcr_compiler.schemas.data_science_data_room import (
    TableLeafNodeV2,
)
from typing_extensions import Self
from .node_definitions import NodeDefinition


class PrimitiveType(str, Enum):
    STRING = "string"
    INTEGER = "integer"
    FLOAT = "float"


class FormatType(str, Enum):
    STRING = "STRING"
    INTEGER = "INTEGER"
    FLOAT = "FLOAT"
    EMAIL = "EMAIL"
    DATE_ISO8601 = "DATE_ISO8601"
    PHONE_NUMBER_E164 = "PHONE_NUMBER_E164"
    HASH_SHA256_HEX = "HASH_SHA256_HEX"

    @staticmethod
    def from_primitive_type(tpe: str) -> FormatType:
        tpe = tpe.lower()
        if tpe == "integer":
            return FormatType.INTEGER
        elif tpe == "float":
            return FormatType.FLOAT
        elif tpe == "string":
            return FormatType.STRING
        else:
            raise Exception(f"Unable to convert data type {tpe} to a format type")

    @staticmethod
    def to_primitive_type(fmt: FormatType) -> str:
        if fmt == FormatType.INTEGER:
            return "integer"
        elif fmt == FormatType.FLOAT:
            return "float"
        elif fmt in {
            FormatType.STRING,
            FormatType.EMAIL,
            FormatType.DATE_ISO8601,
            FormatType.PHONE_NUMBER_E164,
            FormatType.HASH_SHA256_HEX,
        }:
            return "string"
        else:
            raise Exception(f"Unable to convert format type {fmt} to a primitive type")


class HashingAlgorithm(str, Enum):
    SHA256_HEX = "SHA256_HEX"


class NumericRangeRule:
    greater_than: Optional[float] = None
    greater_than_equals: Optional[float] = None
    less_than: Optional[float] = None
    less_than_equals: Optional[float] = None


@dataclass
class Column:
    format_type: FormatType
    name: str
    is_nullable: bool
    hash_with: Optional[HashingAlgorithm] = None
    in_range: Optional[NumericRangeRule] = None


class TableDataNodeDefinition(NodeDefinition):
    """
    Class representing a Table Data Node Definition.
    """

    def __init__(
        self,
        name: str,
        columns: List[Column],
        is_required: bool,
        id: Optional[str] = None,
    ) -> None:
        """
        Initialise a `TableDataNodeDefinition` instance.

        **Parameters**:
        - `name`: Name of the `TableDataNodeDefinition`
        - `columns`: Definition of the columns that make up the `TableDataNodeDefinition`.
        - `is_required`: Flag determining if the `RawDataNode` must be present for dependent computations.
        - `id`: Optional ID of the `TableDataNodeDefinition`
        """
        super().__init__(name, id=id or name)
        self.is_required = is_required
        self.columns = columns
        self.specification_id = "decentriq.python-ml-worker-32-64"
        self.static_content_specification_id = "decentriq.driver"

    def _get_high_level_representation(self) -> Dict[str, str]:
        """
        Retrieve the high level representation of the `TableDataNodeDefinition`.
        """
        column_entries = []
        for column in self.columns:
            validation = {
                "name": column.name,
                "formatType": column.format_type.value,
                "allowNull": column.is_nullable,
            }
            if column.hash_with:
                validation["hashWith"] = column.hash_with.value
            if column.in_range:
                validation["inRange"] = column.in_range.value
            column_entries.append(
                {
                    "name": column.name,
                    "dataFormat": {
                        "isNullable": column.is_nullable,
                        "dataType": FormatType.to_primitive_type(column.format_type),
                    },
                    "validation": validation,
                }
            )

        table_node = {
            "id": self.id,
            "name": self.name,
            "kind": {
                "leaf": {
                    "isRequired": self.is_required,
                    "kind": {
                        "table": {
                            "columns": column_entries,
                            "validationNode": {
                                "staticContentSpecificationId": self.static_content_specification_id,
                                "pythonSpecificationId": self.specification_id,
                                "validation": {},
                            },
                        }
                    },
                }
            },
        }
        return table_node

    @property
    def required_workers(self):
        return [self.static_content_specification_id, self.specification_id]

    @staticmethod
    def _from_high_level(
        id: str,
        name: str,
        node: TableLeafNodeV2,
        is_required: bool,
    ) -> Self:
        """
        Instantiate a `TableDataNodeDefinition` from its high level representation.

        **Parameters**:
        - `name`: Name of the `TableDataNodeDefinition`.
        - `node`: Pydantic model of the `TableDataNodeDefinition`.
        """
        node_dict = json.loads(node.model_dump_json())
        columns = [
            Column(
                name=column["name"],
                format_type=(
                    column["validation"]["formatType"]
                    if "formatType" in column.get("validation")
                    else FormatType.from_primitive_type(
                        column["dataFormat"]["dataType"]
                    )
                ),
                is_nullable=column["dataFormat"]["isNullable"],
                hash_with=column["validation"]["hashWith"],
                in_range=column["validation"]["inRange"],
            )
            for column in node_dict["columns"]
        ]
        return TableDataNodeDefinition(
            id=id,
            name=name,
            columns=columns,
            is_required=is_required,
        )

    def build(
        self,
        dcr_id: str,
        node_definition: NodeDefinition,
        client: Client,
        session: Session,
    ) -> TableDataNode:
        """
        Construct a TableDataNode from the Node Definition.

        **Parameters**:
        - `dcr_id`: ID of the DCR the node is a member of.
        - `node_definition`: Definition of the Table Data Node.
        - `client`: A `Client` object which can be used to perform operations such as uploading data
            and retrieving computation results.
        - `session`: The session with which to communicate with the enclave.
        """
        return TableDataNode(
            name=self.name,
            columns=self.columns,
            is_required=self.is_required,
            dcr_id=dcr_id,
            node_definition=node_definition,
            client=client,
            session=session,
            id=self.id,
        )


class TableDataNode(DataNode):
    """
    Class representing a Table Data Node.
    """

    def __init__(
        self,
        id: str,
        name: str,
        columns: List[Column],
        is_required: bool,
        dcr_id: str,
        client: Client,
        session: Session,
        node_definition: TableDataNodeDefinition,
    ) -> None:
        """
        Initialise a `TableDataNode` instance.

        **Parameters**:
        - 'id': ID of the `TableDataNode`.
        - `name`: Name of the `TableDataNode`
        - `columns`: Definition of the columns that make up the `TableDataNode`.
        - `is_required`: Flag determining if the `TableDataNode` must be present for dependent computations.
        - `dcr_id`: ID of the DCR the node is a member of.
        - `client`: A `Client` object which can be used to perform operations such as uploading data
            and retrieving computation results.
        - `session`: The session with which to communicate with the enclave.
        """
        super().__init__(
            name=name,
            is_required=is_required,
            dcr_id=dcr_id,
            client=client,
            session=session,
            id=id,
            definition=node_definition,
        )
        self.columns = columns

    # This data node needs to override the `super` implementation because
    # the leaf ID requires the "_leaf" suffix.
    def publish_dataset(self, manifest_hash: str, key: Key):
        """
        Publish data to the `TableDataNode`.

        **Parameters**:
        - `manifest_hash`: Hash identifying the dataset to be published.
        - `key`: Encryption key used to decrypt the dataset.
        """
        self.session.publish_dataset(
            self.dcr_id, manifest_hash, leaf_id=f"{self.id}_leaf", key=key
        )

    def get_validation_report_as_dict(self) -> Optional[Dict[str, str]]:
        """
        Retrieve the validation report corresponding to this `TableDataNode`.
        """
        validation_node_id = f"{self.id}_validation_report"
        result = self.session.run_computation_and_get_results(
            self.dcr_id, validation_node_id, interval=1
        )
        if result:
            validation_report = {}
            zip = zipfile.ZipFile(io.BytesIO(result), "r")
            if "validation-report.json" in zip.namelist():
                validation_report = json.loads(
                    zip.read("validation-report.json").decode()
                )
            return validation_report
        else:
            return None

    def remove_published_dataset(self) -> None:
        """
        Removes any dataset that is published to this node.
        """
        self.session.remove_published_dataset(self.dcr_id, f"{self.id}_leaf")



import chily
import os
from hashlib import sha256
from .proto import serialize_length_delimited
from .proto import ChunkHeader, EncryptionHeader, VersionHeader
from typing import BinaryIO, Iterator, Tuple, Optional, List
from io import TextIOWrapper

__all__ = ["Key"]

KEY_LEN = 32


class Key:
    """
    This class wraps the key material that is used to encrypt the
    files that are uploaded to the decentriq platform.
    """

    material: bytes

    def __init__(self, material: Optional[bytes] = None):
        """
        Returns a new `Key` instance, can optional specify the raw key material.
        """
        if material is None:
            key_bytes = os.urandom(KEY_LEN)
        else:
            if len(material) != KEY_LEN:
                raise Exception("Invalid key length, must be 32 bytes")
            key_bytes = material
        self.material = key_bytes


def create_chunk_header(
    extra_entropy: bytes, content_size: Optional[int], chunk_content_sizes: List[int]
) -> bytes:
    chunk_header = ChunkHeader()
    chunk_header.extraEntropy = extra_entropy
    if content_size is not None:
        chunk_header.untrustedContentSize = content_size
    chunk_header.untrustedChunkContentSizes.extend(chunk_content_sizes)

    chunk_header_bytes = serialize_length_delimited(chunk_header)
    return chunk_header_bytes


def create_version_header() -> bytes:
    version_header = VersionHeader()
    version_header.version = 0
    return serialize_length_delimited(version_header)


# Returns (integrity hash, encrypted blob)
def create_encrypted_chunk(
    key: bytes,
    extra_entropy: bytes,
    data: bytes,
    content_size: Optional[int],
    chunk_content_sizes: List[int],
) -> Tuple[bytes, bytes]:
    chunk_bytes = []

    version_header = create_version_header()
    chunk_bytes.append(version_header)

    chunk_header = create_chunk_header(extra_entropy, content_size, chunk_content_sizes)
    chunk_bytes.append(chunk_header)

    chunk_bytes.append(data)

    chunk = b"".join(chunk_bytes)
    chunk_hasher = sha256()
    chunk_hasher.update(chunk)
    chunk_hash = chunk_hasher.digest()

    cipher = StorageCipher(key)
    encrypted_chunk = cipher.encrypt(chunk)

    return chunk_hash, encrypted_chunk


class Chunker(Iterator):
    def __init__(self, input_stream: BinaryIO, chunk_size: int):
        self.chunk_size = chunk_size
        self.content_size = 0
        self.input_stream = input_stream

    def __iter__(self) -> Iterator[Tuple[bytes, bytes]]:
        self.input_stream.seek(0)
        return self

    # returns (hash, chunk, chunk content size)
    def __next__(self) -> Tuple[bytes, bytes, int]:
        version_header_bytes = create_version_header()
        chunk_header_bytes = create_chunk_header(
            os.urandom(16), content_size=None, chunk_content_sizes=[]
        )

        # Does not account for header size
        chunk_bytes = [version_header_bytes, chunk_header_bytes]

        input_chunk_bytes = self.input_stream.read(self.chunk_size)
        chunk_content_size = len(input_chunk_bytes)
        self.content_size += chunk_content_size
        if chunk_content_size == 0:
            raise StopIteration
        chunk_bytes.append(input_chunk_bytes)

        chunk = b"".join(chunk_bytes)
        chunk_hasher = sha256()
        chunk_hasher.update(chunk)
        chunk_hash = chunk_hasher.digest()
        return chunk_hash, chunk, chunk_content_size


class StorageCipher:
    def __init__(self, symmetric_key: bytes):
        self.enc_key = symmetric_key
        self.cipher: chily.Cipher = chily.Cipher.from_symmetric(self.enc_key)

    def encrypt(self, data: bytes) -> bytes:
        nonce = chily.Nonce.from_random()
        encrypted_data = self.cipher.encrypt("storage cipher", data, nonce)

        encryption_header = EncryptionHeader()
        encryption_header.chilyKey.encryptionNonce = bytes(nonce.bytes)

        serialized_encryption_header = serialize_length_delimited(encryption_header)
        encrypted_data_with_header = bytes(
            list(serialized_encryption_header) + encrypted_data
        )
        return encrypted_data_with_header



from typing import List
from ..proto import (
    DriverTaskConfig,
    NoopConfig,
    serialize_length_delimited,
    StaticContentConfig,
    ComputeNodeFormat,
)
from ..decoder import GcgDriverDecoder

from .node import Node


class Noop(Node):
    """
    Computation node which does not perform any operation and produces an empty
    output. This is mostly used to allow users to test the execution of other
    computation nodes without giving access to the results.
    """

    def __init__(self, name: str, dependencies: List[str] = []) -> None:
        config = serialize_length_delimited(DriverTaskConfig(noop=NoopConfig()))
        super().__init__(
            name, config, "decentriq.driver", dependencies, ComputeNodeFormat.RAW
        )


class StaticContent(Node):
    """
    Computation node which outputs the content specified in its configuration.
    This is mostly used to allow users to specify dependencies with a static
    content, which are part of the DCR definition.
    """

    def __init__(self, name: str, content: bytes, dependencies: List[str] = []) -> None:
        """
        Create a node with the given name and content.

        In case the source of the content is a file on your local machine,
        you can open the file in binary mode before reading it:

        ```
        # Note the "rb" argument
        with open("my_script.py", "rb") as data:
            my_script_content = data.read()

        # my_script_content can now be passed to the StaticContent constructor
        ```
        """
        config = serialize_length_delimited(
            DriverTaskConfig(staticContent=StaticContentConfig(content=content))
        )
        super().__init__(
            name,
            config=config,
            enclave_type="decentriq.driver",
            dependencies=dependencies,
            output_format=ComputeNodeFormat.RAW,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compute_container.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x63ompute_container.proto\x12\x11\x63ompute_container\"a\n\x1c\x43ontainerWorkerConfiguration\x12\x30\n\x06static\x18\x01 \x01(\x0b\x32\x1e.compute_container.StaticImageH\x00\x42\x0f\n\rconfiguration\"\xbf\x03\n\x0bStaticImage\x12\x0f\n\x07\x63ommand\x18\x01 \x03(\t\x12\x32\n\x0bmountPoints\x18\x02 \x03(\x0b\x32\x1d.compute_container.MountPoint\x12\x12\n\noutputPath\x18\x03 \x01(\t\x12#\n\x1bincludeContainerLogsOnError\x18\x04 \x01(\x08\x12%\n\x1dincludeContainerLogsOnSuccess\x18\x05 \x01(\x08\x12\'\n\x1aminimumContainerMemorySize\x18\x06 \x01(\x04H\x00\x88\x01\x01\x12\x36\n)extraChunkCacheSizeToAvailableMemoryRatio\x18\x07 \x01(\x02H\x01\x88\x01\x01\x12\x46\n\x12proxyConfiguration\x18\x08 \x01(\x0b\x32%.compute_container.ProxyConfigurationH\x02\x88\x01\x01\x42\x1d\n\x1b_minimumContainerMemorySizeB,\n*_extraChunkCacheSizeToAvailableMemoryRatioB\x15\n\x13_proxyConfiguration\"\xb7\x01\n\x12ProxyConfiguration\x12?\n\x07liberal\x18\x01 \x01(\x0b\x32,.compute_container.ProxyConfigurationLiberalH\x00\x12O\n\x0f\x64omainAllowlist\x18\x02 \x01(\x0b\x32\x34.compute_container.ProxyConfigurationDomainAllowlistH\x00\x42\x0f\n\rconfiguration\"\x1b\n\x19ProxyConfigurationLiberal\"3\n!ProxyConfigurationDomainAllowlist\x12\x0e\n\x06\x64omain\x18\x01 \x03(\t\".\n\nMountPoint\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x12\n\ndependency\x18\x02 \x01(\tb\x06proto3')



_CONTAINERWORKERCONFIGURATION = DESCRIPTOR.message_types_by_name['ContainerWorkerConfiguration']
_STATICIMAGE = DESCRIPTOR.message_types_by_name['StaticImage']
_PROXYCONFIGURATION = DESCRIPTOR.message_types_by_name['ProxyConfiguration']
_PROXYCONFIGURATIONLIBERAL = DESCRIPTOR.message_types_by_name['ProxyConfigurationLiberal']
_PROXYCONFIGURATIONDOMAINALLOWLIST = DESCRIPTOR.message_types_by_name['ProxyConfigurationDomainAllowlist']
_MOUNTPOINT = DESCRIPTOR.message_types_by_name['MountPoint']
ContainerWorkerConfiguration = _reflection.GeneratedProtocolMessageType('ContainerWorkerConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _CONTAINERWORKERCONFIGURATION,
  '__module__' : 'compute_container_pb2'
  # @@protoc_insertion_point(class_scope:compute_container.ContainerWorkerConfiguration)
  })
_sym_db.RegisterMessage(ContainerWorkerConfiguration)

StaticImage = _reflection.GeneratedProtocolMessageType('StaticImage', (_message.Message,), {
  'DESCRIPTOR' : _STATICIMAGE,
  '__module__' : 'compute_container_pb2'
  # @@protoc_insertion_point(class_scope:compute_container.StaticImage)
  })
_sym_db.RegisterMessage(StaticImage)

ProxyConfiguration = _reflection.GeneratedProtocolMessageType('ProxyConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _PROXYCONFIGURATION,
  '__module__' : 'compute_container_pb2'
  # @@protoc_insertion_point(class_scope:compute_container.ProxyConfiguration)
  })
_sym_db.RegisterMessage(ProxyConfiguration)

ProxyConfigurationLiberal = _reflection.GeneratedProtocolMessageType('ProxyConfigurationLiberal', (_message.Message,), {
  'DESCRIPTOR' : _PROXYCONFIGURATIONLIBERAL,
  '__module__' : 'compute_container_pb2'
  # @@protoc_insertion_point(class_scope:compute_container.ProxyConfigurationLiberal)
  })
_sym_db.RegisterMessage(ProxyConfigurationLiberal)

ProxyConfigurationDomainAllowlist = _reflection.GeneratedProtocolMessageType('ProxyConfigurationDomainAllowlist', (_message.Message,), {
  'DESCRIPTOR' : _PROXYCONFIGURATIONDOMAINALLOWLIST,
  '__module__' : 'compute_container_pb2'
  # @@protoc_insertion_point(class_scope:compute_container.ProxyConfigurationDomainAllowlist)
  })
_sym_db.RegisterMessage(ProxyConfigurationDomainAllowlist)

MountPoint = _reflection.GeneratedProtocolMessageType('MountPoint', (_message.Message,), {
  'DESCRIPTOR' : _MOUNTPOINT,
  '__module__' : 'compute_container_pb2'
  # @@protoc_insertion_point(class_scope:compute_container.MountPoint)
  })
_sym_db.RegisterMessage(MountPoint)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONTAINERWORKERCONFIGURATION._serialized_start=46
  _CONTAINERWORKERCONFIGURATION._serialized_end=143
  _STATICIMAGE._serialized_start=146
  _STATICIMAGE._serialized_end=593
  _PROXYCONFIGURATION._serialized_start=596
  _PROXYCONFIGURATION._serialized_end=779
  _PROXYCONFIGURATIONLIBERAL._serialized_start=781
  _PROXYCONFIGURATIONLIBERAL._serialized_end=808
  _PROXYCONFIGURATIONDOMAINALLOWLIST._serialized_start=810
  _PROXYCONFIGURATIONDOMAINALLOWLIST._serialized_end=861
  _MOUNTPOINT._serialized_start=863
  _MOUNTPOINT._serialized_end=909
# @@protoc_insertion_point(module_scope)



from .data_lab import DataLab, DataLabConfig, ExistingDataLab
from .builder import DataLabBuilder
from ..types import DataLabDatasetType, MatchingIdFormat, MatchingId


__pdoc__ = {
    "builder": False,
    "data_lab": False,
}

__all__ = [
    "DataLab",
    "DataLabBuilder",
    "DataLabDatasetType",
    "MatchingId",
    "MatchingIdFormat",
]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google_ad_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17google_ad_manager.proto\x12\x11google_ad_manager\"\x1a\n\nSingleFile\x12\x0c\n\x04name\x18\x01 \x01(\t\"\t\n\x07RawFile\"K\n\x07ZipFile\x12\x33\n\nsingleFile\x18\x01 \x01(\x0b\x32\x1d.google_ad_manager.SingleFileH\x00\x42\x0b\n\tselection\"\x8b\x01\n\tSinkInput\x12\x12\n\ndependency\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12)\n\x03raw\x18\x03 \x01(\x0b\x32\x1a.google_ad_manager.RawFileH\x00\x12)\n\x03zip\x18\x04 \x01(\x0b\x32\x1a.google_ad_manager.ZipFileH\x00\x42\x06\n\x04\x66ile\"\xd5\x01\n\"GoogleAdManagerWorkerConfiguration\x12+\n\x05input\x18\x01 \x01(\x0b\x32\x1c.google_ad_manager.SinkInput\x12\x1d\n\x15\x63redentialsDependency\x18\x02 \x01(\t\x12\x16\n\x0eidentifierKind\x18\x03 \x01(\t\x12\x0e\n\x06listId\x18\x04 \x01(\t\x12\x17\n\x0finputHasHeaders\x18\x05 \x01(\x08\x12\x0e\n\x06\x62ucket\x18\x06 \x01(\t\x12\x12\n\nobjectName\x18\x07 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google_ad_manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SINGLEFILE']._serialized_start=46
  _globals['_SINGLEFILE']._serialized_end=72
  _globals['_RAWFILE']._serialized_start=74
  _globals['_RAWFILE']._serialized_end=83
  _globals['_ZIPFILE']._serialized_start=85
  _globals['_ZIPFILE']._serialized_end=160
  _globals['_SINKINPUT']._serialized_start=163
  _globals['_SINKINPUT']._serialized_end=302
  _globals['_GOOGLEADMANAGERWORKERCONFIGURATION']._serialized_start=305
  _globals['_GOOGLEADMANAGERWORKERCONFIGURATION']._serialized_end=518
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compute_s3_sink.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x63ompute_s3_sink.proto\x12\x0f\x63ompute_s3_sink\"\xb9\x01\n\x19S3SinkWorkerConfiguration\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x0e\n\x06region\x18\x02 \x01(\t\x12\x1d\n\x15\x63redentialsDependency\x18\x03 \x01(\t\x12*\n\x07objects\x18\x04 \x03(\x0b\x32\x19.compute_s3_sink.S3Object\x12/\n\ns3Provider\x18\x05 \x01(\x0e\x32\x1b.compute_s3_sink.S3Provider\"~\n\x08S3Object\x12\x12\n\ndependency\x18\x01 \x01(\t\x12)\n\x03zip\x18\x02 \x01(\x0b\x32\x1a.compute_s3_sink.ZipObjectH\x00\x12)\n\x03raw\x18\x03 \x01(\x0b\x32\x1a.compute_s3_sink.RawObjectH\x00\x42\x08\n\x06\x66ormat\"\x18\n\tRawObject\x12\x0b\n\x03key\x18\x01 \x01(\t\"{\n\tZipObject\x12\x31\n\nsingleFile\x18\x01 \x01(\x0b\x32\x1b.compute_s3_sink.SingleFileH\x00\x12\x33\n\x0b\x66ullContent\x18\x02 \x01(\x0b\x32\x1c.compute_s3_sink.FullContentH\x00\x42\x06\n\x04kind\"\'\n\nSingleFile\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"\r\n\x0b\x46ullContent\"5\n\rS3Credentials\x12\x11\n\taccessKey\x18\x01 \x01(\t\x12\x11\n\tsecretKey\x18\x02 \x01(\t*\x1e\n\nS3Provider\x12\x07\n\x03\x41WS\x10\x00\x12\x07\n\x03GCS\x10\x01\x62\x06proto3')

_S3PROVIDER = DESCRIPTOR.enum_types_by_name['S3Provider']
S3Provider = enum_type_wrapper.EnumTypeWrapper(_S3PROVIDER)
AWS = 0
GCS = 1


_S3SINKWORKERCONFIGURATION = DESCRIPTOR.message_types_by_name['S3SinkWorkerConfiguration']
_S3OBJECT = DESCRIPTOR.message_types_by_name['S3Object']
_RAWOBJECT = DESCRIPTOR.message_types_by_name['RawObject']
_ZIPOBJECT = DESCRIPTOR.message_types_by_name['ZipObject']
_SINGLEFILE = DESCRIPTOR.message_types_by_name['SingleFile']
_FULLCONTENT = DESCRIPTOR.message_types_by_name['FullContent']
_S3CREDENTIALS = DESCRIPTOR.message_types_by_name['S3Credentials']
S3SinkWorkerConfiguration = _reflection.GeneratedProtocolMessageType('S3SinkWorkerConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _S3SINKWORKERCONFIGURATION,
  '__module__' : 'compute_s3_sink_pb2'
  # @@protoc_insertion_point(class_scope:compute_s3_sink.S3SinkWorkerConfiguration)
  })
_sym_db.RegisterMessage(S3SinkWorkerConfiguration)

S3Object = _reflection.GeneratedProtocolMessageType('S3Object', (_message.Message,), {
  'DESCRIPTOR' : _S3OBJECT,
  '__module__' : 'compute_s3_sink_pb2'
  # @@protoc_insertion_point(class_scope:compute_s3_sink.S3Object)
  })
_sym_db.RegisterMessage(S3Object)

RawObject = _reflection.GeneratedProtocolMessageType('RawObject', (_message.Message,), {
  'DESCRIPTOR' : _RAWOBJECT,
  '__module__' : 'compute_s3_sink_pb2'
  # @@protoc_insertion_point(class_scope:compute_s3_sink.RawObject)
  })
_sym_db.RegisterMessage(RawObject)

ZipObject = _reflection.GeneratedProtocolMessageType('ZipObject', (_message.Message,), {
  'DESCRIPTOR' : _ZIPOBJECT,
  '__module__' : 'compute_s3_sink_pb2'
  # @@protoc_insertion_point(class_scope:compute_s3_sink.ZipObject)
  })
_sym_db.RegisterMessage(ZipObject)

SingleFile = _reflection.GeneratedProtocolMessageType('SingleFile', (_message.Message,), {
  'DESCRIPTOR' : _SINGLEFILE,
  '__module__' : 'compute_s3_sink_pb2'
  # @@protoc_insertion_point(class_scope:compute_s3_sink.SingleFile)
  })
_sym_db.RegisterMessage(SingleFile)

FullContent = _reflection.GeneratedProtocolMessageType('FullContent', (_message.Message,), {
  'DESCRIPTOR' : _FULLCONTENT,
  '__module__' : 'compute_s3_sink_pb2'
  # @@protoc_insertion_point(class_scope:compute_s3_sink.FullContent)
  })
_sym_db.RegisterMessage(FullContent)

S3Credentials = _reflection.GeneratedProtocolMessageType('S3Credentials', (_message.Message,), {
  'DESCRIPTOR' : _S3CREDENTIALS,
  '__module__' : 'compute_s3_sink_pb2'
  # @@protoc_insertion_point(class_scope:compute_s3_sink.S3Credentials)
  })
_sym_db.RegisterMessage(S3Credentials)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _S3PROVIDER._serialized_start=620
  _S3PROVIDER._serialized_end=650
  _S3SINKWORKERCONFIGURATION._serialized_start=43
  _S3SINKWORKERCONFIGURATION._serialized_end=228
  _S3OBJECT._serialized_start=230
  _S3OBJECT._serialized_end=356
  _RAWOBJECT._serialized_start=358
  _RAWOBJECT._serialized_end=382
  _ZIPOBJECT._serialized_start=384
  _ZIPOBJECT._serialized_end=507
  _SINGLEFILE._serialized_start=509
  _SINGLEFILE._serialized_end=548
  _FULLCONTENT._serialized_start=550
  _FULLCONTENT._serialized_end=563
  _S3CREDENTIALS._serialized_start=565
  _S3CREDENTIALS._serialized_end=618
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dataset_sink.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x64\x61taset_sink.proto\x12\x0c\x64\x61taset_sink\"\t\n\x07RawFile\"\n\n\x08\x41llFiles\">\n\nSingleFile\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\x08renameAs\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_renameAs\"8\n\rFileSelection\x12\'\n\x05names\x18\x01 \x03(\x0b\x32\x18.dataset_sink.SingleFile\"k\n\x07ZipFile\x12%\n\x03\x61ll\x18\x01 \x01(\x0b\x32\x16.dataset_sink.AllFilesH\x00\x12,\n\x05\x66iles\x18\x02 \x01(\x0b\x32\x1b.dataset_sink.FileSelectionH\x00\x42\x0b\n\tselection\"\x81\x01\n\tSinkInput\x12\x12\n\ndependency\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12$\n\x03raw\x18\x03 \x01(\x0b\x32\x15.dataset_sink.RawFileH\x00\x12$\n\x03zip\x18\x04 \x01(\x0b\x32\x15.dataset_sink.ZipFileH\x00\x42\x06\n\x04\x66ile\"\xb5\x01\n\x1e\x44\x61tasetSinkWorkerConfiguration\x12\'\n\x06inputs\x18\x01 \x03(\x0b\x32\x17.dataset_sink.SinkInput\x12\x1f\n\x17\x65ncryptionKeyDependency\x18\x02 \x01(\t\x12\x1c\n\x0f\x64\x61tasetImportId\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x17\n\x0fisKeyHexEncoded\x18\x04 \x01(\x08\x42\x12\n\x10_datasetImportIdb\x06proto3')



_RAWFILE = DESCRIPTOR.message_types_by_name['RawFile']
_ALLFILES = DESCRIPTOR.message_types_by_name['AllFiles']
_SINGLEFILE = DESCRIPTOR.message_types_by_name['SingleFile']
_FILESELECTION = DESCRIPTOR.message_types_by_name['FileSelection']
_ZIPFILE = DESCRIPTOR.message_types_by_name['ZipFile']
_SINKINPUT = DESCRIPTOR.message_types_by_name['SinkInput']
_DATASETSINKWORKERCONFIGURATION = DESCRIPTOR.message_types_by_name['DatasetSinkWorkerConfiguration']
RawFile = _reflection.GeneratedProtocolMessageType('RawFile', (_message.Message,), {
  'DESCRIPTOR' : _RAWFILE,
  '__module__' : 'dataset_sink_pb2'
  # @@protoc_insertion_point(class_scope:dataset_sink.RawFile)
  })
_sym_db.RegisterMessage(RawFile)

AllFiles = _reflection.GeneratedProtocolMessageType('AllFiles', (_message.Message,), {
  'DESCRIPTOR' : _ALLFILES,
  '__module__' : 'dataset_sink_pb2'
  # @@protoc_insertion_point(class_scope:dataset_sink.AllFiles)
  })
_sym_db.RegisterMessage(AllFiles)

SingleFile = _reflection.GeneratedProtocolMessageType('SingleFile', (_message.Message,), {
  'DESCRIPTOR' : _SINGLEFILE,
  '__module__' : 'dataset_sink_pb2'
  # @@protoc_insertion_point(class_scope:dataset_sink.SingleFile)
  })
_sym_db.RegisterMessage(SingleFile)

FileSelection = _reflection.GeneratedProtocolMessageType('FileSelection', (_message.Message,), {
  'DESCRIPTOR' : _FILESELECTION,
  '__module__' : 'dataset_sink_pb2'
  # @@protoc_insertion_point(class_scope:dataset_sink.FileSelection)
  })
_sym_db.RegisterMessage(FileSelection)

ZipFile = _reflection.GeneratedProtocolMessageType('ZipFile', (_message.Message,), {
  'DESCRIPTOR' : _ZIPFILE,
  '__module__' : 'dataset_sink_pb2'
  # @@protoc_insertion_point(class_scope:dataset_sink.ZipFile)
  })
_sym_db.RegisterMessage(ZipFile)

SinkInput = _reflection.GeneratedProtocolMessageType('SinkInput', (_message.Message,), {
  'DESCRIPTOR' : _SINKINPUT,
  '__module__' : 'dataset_sink_pb2'
  # @@protoc_insertion_point(class_scope:dataset_sink.SinkInput)
  })
_sym_db.RegisterMessage(SinkInput)

DatasetSinkWorkerConfiguration = _reflection.GeneratedProtocolMessageType('DatasetSinkWorkerConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _DATASETSINKWORKERCONFIGURATION,
  '__module__' : 'dataset_sink_pb2'
  # @@protoc_insertion_point(class_scope:dataset_sink.DatasetSinkWorkerConfiguration)
  })
_sym_db.RegisterMessage(DatasetSinkWorkerConfiguration)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RAWFILE._serialized_start=36
  _RAWFILE._serialized_end=45
  _ALLFILES._serialized_start=47
  _ALLFILES._serialized_end=57
  _SINGLEFILE._serialized_start=59
  _SINGLEFILE._serialized_end=121
  _FILESELECTION._serialized_start=123
  _FILESELECTION._serialized_end=179
  _ZIPFILE._serialized_start=181
  _ZIPFILE._serialized_end=288
  _SINKINPUT._serialized_start=291
  _SINKINPUT._serialized_end=420
  _DATASETSINKWORKERCONFIGURATION._serialized_start=423
  _DATASETSINKWORKERCONFIGURATION._serialized_end=604
# @@protoc_insertion_point(module_scope)



"""
.. include:: ../../decentriq_platform_docs/gcg_getting_started.md
___
"""

from .client import Client, create_client, Session
from .storage import Key
from .attestation import enclave_specifications, EnclaveSpecifications

from .endorsement import Endorser
from .keychain import Keychain, KeychainEntry

from . import analytics
from . import lookalike_media
from . import legacy
from . import data_lab
from . import session

__docformat__ = "restructuredtext"

__pdoc__ = {
    "api": False,
    "attestation": True,
    "authentication": True,
    "builders": False,
    "certs": False,
    "client": False,
    "compute": False,
    "config": False,
    "graphql": False,
    "helpers": False,
    "proto": False,
    "lookalike_media": True,
    "session": False,
    "storage": False,
    "types": False,
    "verification": False,
    "data_lab": True,
    "legacy": True,
    "decoder": False,
}

__all__ = [
    "create_client",
    "Client",
    "Session",
    "enclave_specifications",
    "EnclaveSpecifications",
    "Key",
    "KeychainEntry",
    "lookalike_media",
    "storage",
    "attestation",
    "types",
    "authentication",
    "session",
    "Endorser",
    "Keychain",
    "data_lab",
    "legacy",
    "analytics",
]
